# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpc.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\trpc.proto\"O\n\x15\x63riu_page_server_info\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x0b\n\x03pid\x18\x03 \x01(\x05\x12\n\n\x02\x66\x64\x18\x04 \x01(\x05\"/\n\x0e\x63riu_veth_pair\x12\r\n\x05if_in\x18\x01 \x02(\t\x12\x0e\n\x06if_out\x18\x02 \x02(\t\")\n\rext_mount_map\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\x0b\n\x03val\x18\x02 \x02(\t\"@\n\x0ejoin_namespace\x12\n\n\x02ns\x18\x01 \x02(\t\x12\x0f\n\x07ns_file\x18\x02 \x02(\t\x12\x11\n\textra_opt\x18\x03 \x01(\t\"%\n\ninherit_fd\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\n\n\x02\x66\x64\x18\x02 \x02(\x05\")\n\x0b\x63group_root\x12\x0c\n\x04\x63trl\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\"\x18\n\x07unix_sk\x12\r\n\x05inode\x18\x01 \x02(\r\"\xd8\n\n\tcriu_opts\x12\x15\n\rimages_dir_fd\x18\x01 \x02(\x05\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x15\n\rleave_running\x18\x03 \x01(\x08\x12\x13\n\x0b\x65xt_unix_sk\x18\x04 \x01(\x08\x12\x17\n\x0ftcp_established\x18\x05 \x01(\x08\x12\x17\n\x0f\x65vasive_devices\x18\x06 \x01(\x08\x12\x11\n\tshell_job\x18\x07 \x01(\x08\x12\x12\n\nfile_locks\x18\x08 \x01(\x08\x12\x14\n\tlog_level\x18\t \x01(\x05:\x01\x32\x12\x10\n\x08log_file\x18\n \x01(\t\x12\"\n\x02ps\x18\x0b \x01(\x0b\x32\x16.criu_page_server_info\x12\x16\n\x0enotify_scripts\x18\x0c \x01(\x08\x12\x0c\n\x04root\x18\r \x01(\t\x12\x12\n\nparent_img\x18\x0e \x01(\t\x12\x11\n\ttrack_mem\x18\x0f \x01(\x08\x12\x12\n\nauto_dedup\x18\x10 \x01(\x08\x12\x13\n\x0bwork_dir_fd\x18\x11 \x01(\x05\x12\x12\n\nlink_remap\x18\x12 \x01(\x08\x12\x1e\n\x05veths\x18\x13 \x03(\x0b\x32\x0f.criu_veth_pair\x12\x1b\n\x07\x63pu_cap\x18\x14 \x01(\r:\n4294967295\x12\x13\n\x0b\x66orce_irmap\x18\x15 \x01(\x08\x12\x10\n\x08\x65xec_cmd\x18\x16 \x03(\t\x12\x1f\n\x07\x65xt_mnt\x18\x17 \x03(\x0b\x32\x0e.ext_mount_map\x12\x16\n\x0emanage_cgroups\x18\x18 \x01(\x08\x12\x1d\n\x07\x63g_root\x18\x19 \x03(\x0b\x32\x0c.cgroup_root\x12\x13\n\x0brst_sibling\x18\x1a \x01(\x08\x12\x1f\n\ninherit_fd\x18\x1b \x03(\x0b\x32\x0b.inherit_fd\x12\x14\n\x0c\x61uto_ext_mnt\x18\x1c \x01(\x08\x12\x13\n\x0b\x65xt_sharing\x18\x1d \x01(\x08\x12\x13\n\x0b\x65xt_masters\x18\x1e \x01(\x08\x12\x10\n\x08skip_mnt\x18\x1f \x03(\t\x12\x11\n\tenable_fs\x18  \x03(\t\x12\x1d\n\x0bunix_sk_ino\x18! \x03(\x0b\x32\x08.unix_sk\x12*\n\x13manage_cgroups_mode\x18\" \x01(\x0e\x32\r.criu_cg_mode\x12\x1c\n\x0bghost_limit\x18# \x01(\r:\x07\x31\x30\x34\x38\x35\x37\x36\x12\x18\n\x10irmap_scan_paths\x18$ \x03(\t\x12\x10\n\x08\x65xternal\x18% \x03(\t\x12\x10\n\x08\x65mpty_ns\x18& \x01(\r\x12 \n\x07join_ns\x18\' \x03(\x0b\x32\x0f.join_namespace\x12\x14\n\x0c\x63group_props\x18) \x01(\t\x12\x19\n\x11\x63group_props_file\x18* \x01(\t\x12\x1e\n\x16\x63group_dump_controller\x18+ \x03(\t\x12\x15\n\rfreeze_cgroup\x18, \x01(\t\x12\x0f\n\x07timeout\x18- \x01(\r\x12\x1a\n\x12tcp_skip_in_flight\x18. \x01(\x08\x12\x14\n\x0cweak_sysctls\x18/ \x01(\x08\x12\x12\n\nlazy_pages\x18\x30 \x01(\x08\x12\x11\n\tstatus_fd\x18\x31 \x01(\x05\x12\x19\n\x11orphan_pts_master\x18\x32 \x01(\x08\x12\x13\n\x0b\x63onfig_file\x18\x33 \x01(\t\x12\x11\n\ttcp_close\x18\x34 \x01(\x08\x12\x13\n\x0blsm_profile\x18\x35 \x01(\t\x12\x12\n\ntls_cacert\x18\x36 \x01(\t\x12\x11\n\ttls_cacrl\x18\x37 \x01(\t\x12\x10\n\x08tls_cert\x18\x38 \x01(\t\x12\x0f\n\x07tls_key\x18\x39 \x01(\t\x12\x0b\n\x03tls\x18: \x01(\x08\x12\x18\n\x10tls_no_cn_verify\x18; \x01(\x08\x12\x11\n\troot_only\x18< \x01(\x08\"\"\n\x0e\x63riu_dump_resp\x12\x10\n\x08restored\x18\x01 \x01(\x08\" \n\x11\x63riu_restore_resp\x12\x0b\n\x03pid\x18\x01 \x02(\x05\"*\n\x0b\x63riu_notify\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\"6\n\rcriu_features\x12\x11\n\tmem_track\x18\x01 \x01(\x08\x12\x12\n\nlazy_pages\x18\x02 \x01(\x08\"\x9c\x01\n\x08\x63riu_req\x12\x1c\n\x04type\x18\x01 \x02(\x0e\x32\x0e.criu_req_type\x12\x18\n\x04opts\x18\x02 \x01(\x0b\x32\n.criu_opts\x12\x16\n\x0enotify_success\x18\x03 \x01(\x08\x12\x11\n\tkeep_open\x18\x04 \x01(\x08\x12 \n\x08\x66\x65\x61tures\x18\x05 \x01(\x0b\x32\x0e.criu_features\x12\x0b\n\x03pid\x18\x06 \x01(\r\"\xb7\x02\n\tcriu_resp\x12\x1c\n\x04type\x18\x01 \x02(\x0e\x32\x0e.criu_req_type\x12\x0f\n\x07success\x18\x02 \x02(\x08\x12\x1d\n\x04\x64ump\x18\x03 \x01(\x0b\x32\x0f.criu_dump_resp\x12#\n\x07restore\x18\x04 \x01(\x0b\x32\x12.criu_restore_resp\x12\x1c\n\x06notify\x18\x05 \x01(\x0b\x32\x0c.criu_notify\x12\"\n\x02ps\x18\x06 \x01(\x0b\x32\x16.criu_page_server_info\x12\x10\n\x08\x63r_errno\x18\x07 \x01(\x05\x12 \n\x08\x66\x65\x61tures\x18\x08 \x01(\x0b\x32\x0e.criu_features\x12\x11\n\tcr_errmsg\x18\t \x01(\t\x12\x1e\n\x07version\x18\n \x01(\x0b\x32\r.criu_version\x12\x0e\n\x06status\x18\x0b \x01(\x05\"x\n\x0c\x63riu_version\x12\x14\n\x0cmajor_number\x18\x01 \x02(\x05\x12\x14\n\x0cminor_number\x18\x02 \x02(\x05\x12\r\n\x05gitid\x18\x03 \x01(\t\x12\x10\n\x08sublevel\x18\x04 \x01(\x05\x12\r\n\x05\x65xtra\x18\x05 \x01(\x05\x12\x0c\n\x04name\x18\x06 \x01(\t*_\n\x0c\x63riu_cg_mode\x12\n\n\x06IGNORE\x10\x00\x12\x0b\n\x07\x43G_NONE\x10\x01\x12\t\n\x05PROPS\x10\x02\x12\x08\n\x04SOFT\x10\x03\x12\x08\n\x04\x46ULL\x10\x04\x12\n\n\x06STRICT\x10\x05\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x06*\xd0\x01\n\rcriu_req_type\x12\t\n\x05\x45MPTY\x10\x00\x12\x08\n\x04\x44UMP\x10\x01\x12\x0b\n\x07RESTORE\x10\x02\x12\t\n\x05\x43HECK\x10\x03\x12\x0c\n\x08PRE_DUMP\x10\x04\x12\x0f\n\x0bPAGE_SERVER\x10\x05\x12\n\n\x06NOTIFY\x10\x06\x12\x10\n\x0c\x43PUINFO_DUMP\x10\x07\x12\x11\n\rCPUINFO_CHECK\x10\x08\x12\x11\n\rFEATURE_CHECK\x10\t\x12\x0b\n\x07VERSION\x10\n\x12\x0c\n\x08WAIT_PID\x10\x0b\x12\x14\n\x10PAGE_SERVER_CHLD\x10\x0c')
)

_CRIU_CG_MODE = _descriptor.EnumDescriptor(
  name='criu_cg_mode',
  full_name='criu_cg_mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IGNORE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CG_NONE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROPS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOFT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRICT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2496,
  serialized_end=2591,
)
_sym_db.RegisterEnumDescriptor(_CRIU_CG_MODE)

criu_cg_mode = enum_type_wrapper.EnumTypeWrapper(_CRIU_CG_MODE)
_CRIU_REQ_TYPE = _descriptor.EnumDescriptor(
  name='criu_req_type',
  full_name='criu_req_type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUMP', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESTORE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHECK', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRE_DUMP', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAGE_SERVER', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOTIFY', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CPUINFO_DUMP', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CPUINFO_CHECK', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_CHECK', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERSION', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAIT_PID', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAGE_SERVER_CHLD', index=12, number=12,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2594,
  serialized_end=2802,
)
_sym_db.RegisterEnumDescriptor(_CRIU_REQ_TYPE)

criu_req_type = enum_type_wrapper.EnumTypeWrapper(_CRIU_REQ_TYPE)
IGNORE = 0
CG_NONE = 1
PROPS = 2
SOFT = 3
FULL = 4
STRICT = 5
DEFAULT = 6
EMPTY = 0
DUMP = 1
RESTORE = 2
CHECK = 3
PRE_DUMP = 4
PAGE_SERVER = 5
NOTIFY = 6
CPUINFO_DUMP = 7
CPUINFO_CHECK = 8
FEATURE_CHECK = 9
VERSION = 10
WAIT_PID = 11
PAGE_SERVER_CHLD = 12



_CRIU_PAGE_SERVER_INFO = _descriptor.Descriptor(
  name='criu_page_server_info',
  full_name='criu_page_server_info',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='criu_page_server_info.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='criu_page_server_info.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_page_server_info.pid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fd', full_name='criu_page_server_info.fd', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13,
  serialized_end=92,
)


_CRIU_VETH_PAIR = _descriptor.Descriptor(
  name='criu_veth_pair',
  full_name='criu_veth_pair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='if_in', full_name='criu_veth_pair.if_in', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='if_out', full_name='criu_veth_pair.if_out', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=141,
)


_EXT_MOUNT_MAP = _descriptor.Descriptor(
  name='ext_mount_map',
  full_name='ext_mount_map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ext_mount_map.key', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='ext_mount_map.val', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=184,
)


_JOIN_NAMESPACE = _descriptor.Descriptor(
  name='join_namespace',
  full_name='join_namespace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ns', full_name='join_namespace.ns', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_file', full_name='join_namespace.ns_file', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_opt', full_name='join_namespace.extra_opt', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=250,
)


_INHERIT_FD = _descriptor.Descriptor(
  name='inherit_fd',
  full_name='inherit_fd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='inherit_fd.key', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fd', full_name='inherit_fd.fd', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=289,
)


_CGROUP_ROOT = _descriptor.Descriptor(
  name='cgroup_root',
  full_name='cgroup_root',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ctrl', full_name='cgroup_root.ctrl', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='cgroup_root.path', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=332,
)


_UNIX_SK = _descriptor.Descriptor(
  name='unix_sk',
  full_name='unix_sk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inode', full_name='unix_sk.inode', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=358,
)


_CRIU_OPTS = _descriptor.Descriptor(
  name='criu_opts',
  full_name='criu_opts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='images_dir_fd', full_name='criu_opts.images_dir_fd', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_opts.pid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leave_running', full_name='criu_opts.leave_running', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_unix_sk', full_name='criu_opts.ext_unix_sk', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcp_established', full_name='criu_opts.tcp_established', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evasive_devices', full_name='criu_opts.evasive_devices', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shell_job', full_name='criu_opts.shell_job', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_locks', full_name='criu_opts.file_locks', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_level', full_name='criu_opts.log_level', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_file', full_name='criu_opts.log_file', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ps', full_name='criu_opts.ps', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notify_scripts', full_name='criu_opts.notify_scripts', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root', full_name='criu_opts.root', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_img', full_name='criu_opts.parent_img', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='track_mem', full_name='criu_opts.track_mem', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_dedup', full_name='criu_opts.auto_dedup', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='work_dir_fd', full_name='criu_opts.work_dir_fd', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link_remap', full_name='criu_opts.link_remap', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='veths', full_name='criu_opts.veths', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_cap', full_name='criu_opts.cpu_cap', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4294967295,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_irmap', full_name='criu_opts.force_irmap', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exec_cmd', full_name='criu_opts.exec_cmd', index=21,
      number=22, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_mnt', full_name='criu_opts.ext_mnt', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manage_cgroups', full_name='criu_opts.manage_cgroups', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cg_root', full_name='criu_opts.cg_root', index=24,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rst_sibling', full_name='criu_opts.rst_sibling', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inherit_fd', full_name='criu_opts.inherit_fd', index=26,
      number=27, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_ext_mnt', full_name='criu_opts.auto_ext_mnt', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_sharing', full_name='criu_opts.ext_sharing', index=28,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_masters', full_name='criu_opts.ext_masters', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skip_mnt', full_name='criu_opts.skip_mnt', index=30,
      number=31, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_fs', full_name='criu_opts.enable_fs', index=31,
      number=32, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unix_sk_ino', full_name='criu_opts.unix_sk_ino', index=32,
      number=33, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manage_cgroups_mode', full_name='criu_opts.manage_cgroups_mode', index=33,
      number=34, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ghost_limit', full_name='criu_opts.ghost_limit', index=34,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1048576,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='irmap_scan_paths', full_name='criu_opts.irmap_scan_paths', index=35,
      number=36, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external', full_name='criu_opts.external', index=36,
      number=37, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty_ns', full_name='criu_opts.empty_ns', index=37,
      number=38, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='join_ns', full_name='criu_opts.join_ns', index=38,
      number=39, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cgroup_props', full_name='criu_opts.cgroup_props', index=39,
      number=41, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cgroup_props_file', full_name='criu_opts.cgroup_props_file', index=40,
      number=42, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cgroup_dump_controller', full_name='criu_opts.cgroup_dump_controller', index=41,
      number=43, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freeze_cgroup', full_name='criu_opts.freeze_cgroup', index=42,
      number=44, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='criu_opts.timeout', index=43,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcp_skip_in_flight', full_name='criu_opts.tcp_skip_in_flight', index=44,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weak_sysctls', full_name='criu_opts.weak_sysctls', index=45,
      number=47, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lazy_pages', full_name='criu_opts.lazy_pages', index=46,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status_fd', full_name='criu_opts.status_fd', index=47,
      number=49, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orphan_pts_master', full_name='criu_opts.orphan_pts_master', index=48,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_file', full_name='criu_opts.config_file', index=49,
      number=51, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcp_close', full_name='criu_opts.tcp_close', index=50,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lsm_profile', full_name='criu_opts.lsm_profile', index=51,
      number=53, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_cacert', full_name='criu_opts.tls_cacert', index=52,
      number=54, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_cacrl', full_name='criu_opts.tls_cacrl', index=53,
      number=55, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_cert', full_name='criu_opts.tls_cert', index=54,
      number=56, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_key', full_name='criu_opts.tls_key', index=55,
      number=57, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls', full_name='criu_opts.tls', index=56,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls_no_cn_verify', full_name='criu_opts.tls_no_cn_verify', index=57,
      number=59, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_only', full_name='criu_opts.root_only', index=58,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=1729,
)


_CRIU_DUMP_RESP = _descriptor.Descriptor(
  name='criu_dump_resp',
  full_name='criu_dump_resp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='restored', full_name='criu_dump_resp.restored', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1731,
  serialized_end=1765,
)


_CRIU_RESTORE_RESP = _descriptor.Descriptor(
  name='criu_restore_resp',
  full_name='criu_restore_resp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_restore_resp.pid', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1767,
  serialized_end=1799,
)


_CRIU_NOTIFY = _descriptor.Descriptor(
  name='criu_notify',
  full_name='criu_notify',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='script', full_name='criu_notify.script', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_notify.pid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1801,
  serialized_end=1843,
)


_CRIU_FEATURES = _descriptor.Descriptor(
  name='criu_features',
  full_name='criu_features',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mem_track', full_name='criu_features.mem_track', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lazy_pages', full_name='criu_features.lazy_pages', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1845,
  serialized_end=1899,
)


_CRIU_REQ = _descriptor.Descriptor(
  name='criu_req',
  full_name='criu_req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='criu_req.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opts', full_name='criu_req.opts', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notify_success', full_name='criu_req.notify_success', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_open', full_name='criu_req.keep_open', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features', full_name='criu_req.features', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='criu_req.pid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1902,
  serialized_end=2058,
)


_CRIU_RESP = _descriptor.Descriptor(
  name='criu_resp',
  full_name='criu_resp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='criu_resp.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='criu_resp.success', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dump', full_name='criu_resp.dump', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore', full_name='criu_resp.restore', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notify', full_name='criu_resp.notify', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ps', full_name='criu_resp.ps', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cr_errno', full_name='criu_resp.cr_errno', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features', full_name='criu_resp.features', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cr_errmsg', full_name='criu_resp.cr_errmsg', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='criu_resp.version', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='criu_resp.status', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2061,
  serialized_end=2372,
)


_CRIU_VERSION = _descriptor.Descriptor(
  name='criu_version',
  full_name='criu_version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='major_number', full_name='criu_version.major_number', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minor_number', full_name='criu_version.minor_number', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gitid', full_name='criu_version.gitid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sublevel', full_name='criu_version.sublevel', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='criu_version.extra', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='criu_version.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2374,
  serialized_end=2494,
)

_CRIU_OPTS.fields_by_name['ps'].message_type = _CRIU_PAGE_SERVER_INFO
_CRIU_OPTS.fields_by_name['veths'].message_type = _CRIU_VETH_PAIR
_CRIU_OPTS.fields_by_name['ext_mnt'].message_type = _EXT_MOUNT_MAP
_CRIU_OPTS.fields_by_name['cg_root'].message_type = _CGROUP_ROOT
_CRIU_OPTS.fields_by_name['inherit_fd'].message_type = _INHERIT_FD
_CRIU_OPTS.fields_by_name['unix_sk_ino'].message_type = _UNIX_SK
_CRIU_OPTS.fields_by_name['manage_cgroups_mode'].enum_type = _CRIU_CG_MODE
_CRIU_OPTS.fields_by_name['join_ns'].message_type = _JOIN_NAMESPACE
_CRIU_REQ.fields_by_name['type'].enum_type = _CRIU_REQ_TYPE
_CRIU_REQ.fields_by_name['opts'].message_type = _CRIU_OPTS
_CRIU_REQ.fields_by_name['features'].message_type = _CRIU_FEATURES
_CRIU_RESP.fields_by_name['type'].enum_type = _CRIU_REQ_TYPE
_CRIU_RESP.fields_by_name['dump'].message_type = _CRIU_DUMP_RESP
_CRIU_RESP.fields_by_name['restore'].message_type = _CRIU_RESTORE_RESP
_CRIU_RESP.fields_by_name['notify'].message_type = _CRIU_NOTIFY
_CRIU_RESP.fields_by_name['ps'].message_type = _CRIU_PAGE_SERVER_INFO
_CRIU_RESP.fields_by_name['features'].message_type = _CRIU_FEATURES
_CRIU_RESP.fields_by_name['version'].message_type = _CRIU_VERSION
DESCRIPTOR.message_types_by_name['criu_page_server_info'] = _CRIU_PAGE_SERVER_INFO
DESCRIPTOR.message_types_by_name['criu_veth_pair'] = _CRIU_VETH_PAIR
DESCRIPTOR.message_types_by_name['ext_mount_map'] = _EXT_MOUNT_MAP
DESCRIPTOR.message_types_by_name['join_namespace'] = _JOIN_NAMESPACE
DESCRIPTOR.message_types_by_name['inherit_fd'] = _INHERIT_FD
DESCRIPTOR.message_types_by_name['cgroup_root'] = _CGROUP_ROOT
DESCRIPTOR.message_types_by_name['unix_sk'] = _UNIX_SK
DESCRIPTOR.message_types_by_name['criu_opts'] = _CRIU_OPTS
DESCRIPTOR.message_types_by_name['criu_dump_resp'] = _CRIU_DUMP_RESP
DESCRIPTOR.message_types_by_name['criu_restore_resp'] = _CRIU_RESTORE_RESP
DESCRIPTOR.message_types_by_name['criu_notify'] = _CRIU_NOTIFY
DESCRIPTOR.message_types_by_name['criu_features'] = _CRIU_FEATURES
DESCRIPTOR.message_types_by_name['criu_req'] = _CRIU_REQ
DESCRIPTOR.message_types_by_name['criu_resp'] = _CRIU_RESP
DESCRIPTOR.message_types_by_name['criu_version'] = _CRIU_VERSION
DESCRIPTOR.enum_types_by_name['criu_cg_mode'] = _CRIU_CG_MODE
DESCRIPTOR.enum_types_by_name['criu_req_type'] = _CRIU_REQ_TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

criu_page_server_info = _reflection.GeneratedProtocolMessageType('criu_page_server_info', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_PAGE_SERVER_INFO,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_page_server_info)
  ))
_sym_db.RegisterMessage(criu_page_server_info)

criu_veth_pair = _reflection.GeneratedProtocolMessageType('criu_veth_pair', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_VETH_PAIR,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_veth_pair)
  ))
_sym_db.RegisterMessage(criu_veth_pair)

ext_mount_map = _reflection.GeneratedProtocolMessageType('ext_mount_map', (_message.Message,), dict(
  DESCRIPTOR = _EXT_MOUNT_MAP,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:ext_mount_map)
  ))
_sym_db.RegisterMessage(ext_mount_map)

join_namespace = _reflection.GeneratedProtocolMessageType('join_namespace', (_message.Message,), dict(
  DESCRIPTOR = _JOIN_NAMESPACE,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:join_namespace)
  ))
_sym_db.RegisterMessage(join_namespace)

inherit_fd = _reflection.GeneratedProtocolMessageType('inherit_fd', (_message.Message,), dict(
  DESCRIPTOR = _INHERIT_FD,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:inherit_fd)
  ))
_sym_db.RegisterMessage(inherit_fd)

cgroup_root = _reflection.GeneratedProtocolMessageType('cgroup_root', (_message.Message,), dict(
  DESCRIPTOR = _CGROUP_ROOT,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:cgroup_root)
  ))
_sym_db.RegisterMessage(cgroup_root)

unix_sk = _reflection.GeneratedProtocolMessageType('unix_sk', (_message.Message,), dict(
  DESCRIPTOR = _UNIX_SK,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:unix_sk)
  ))
_sym_db.RegisterMessage(unix_sk)

criu_opts = _reflection.GeneratedProtocolMessageType('criu_opts', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_OPTS,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_opts)
  ))
_sym_db.RegisterMessage(criu_opts)

criu_dump_resp = _reflection.GeneratedProtocolMessageType('criu_dump_resp', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_DUMP_RESP,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_dump_resp)
  ))
_sym_db.RegisterMessage(criu_dump_resp)

criu_restore_resp = _reflection.GeneratedProtocolMessageType('criu_restore_resp', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_RESTORE_RESP,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_restore_resp)
  ))
_sym_db.RegisterMessage(criu_restore_resp)

criu_notify = _reflection.GeneratedProtocolMessageType('criu_notify', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_NOTIFY,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_notify)
  ))
_sym_db.RegisterMessage(criu_notify)

criu_features = _reflection.GeneratedProtocolMessageType('criu_features', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_FEATURES,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_features)
  ))
_sym_db.RegisterMessage(criu_features)

criu_req = _reflection.GeneratedProtocolMessageType('criu_req', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_REQ,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_req)
  ))
_sym_db.RegisterMessage(criu_req)

criu_resp = _reflection.GeneratedProtocolMessageType('criu_resp', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_RESP,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_resp)
  ))
_sym_db.RegisterMessage(criu_resp)

criu_version = _reflection.GeneratedProtocolMessageType('criu_version', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_VERSION,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:criu_version)
  ))
_sym_db.RegisterMessage(criu_version)


# @@protoc_insertion_point(module_scope)
