# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core-s390.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core-s390.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0f\x63ore-s390.proto\x1a\nopts.proto\"~\n\x14user_s390_regs_entry\x12\x10\n\x08psw_mask\x18\x01 \x02(\x04\x12\x10\n\x08psw_addr\x18\x02 \x02(\x04\x12\x0c\n\x04gprs\x18\x03 \x03(\x04\x12\x0c\n\x04\x61\x63rs\x18\x04 \x03(\r\x12\x11\n\torig_gpr2\x18\x05 \x02(\x04\x12\x13\n\x0bsystem_call\x18\x06 \x02(\r\"(\n\x18user_s390_vxrs_low_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\")\n\x19user_s390_vxrs_high_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\"3\n\x16user_s390_fpregs_entry\x12\x0b\n\x03\x66pc\x18\x01 \x02(\r\x12\x0c\n\x04\x66prs\x18\x02 \x03(\x04\"%\n\x15user_s390_gs_cb_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\"1\n\x12user_s390_ri_entry\x12\r\n\x05ri_on\x18\x01 \x02(\r\x12\x0c\n\x04regs\x18\x02 \x03(\x04\"\x80\x03\n\x10thread_info_s390\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12,\n\x06gpregs\x18\x02 \x02(\x0b\x32\x15.user_s390_regs_entryB\x05\xd2?\x02\x08\x01\x12.\n\x06\x66pregs\x18\x03 \x02(\x0b\x32\x17.user_s390_fpregs_entryB\x05\xd2?\x02\x08\x01\x12\x32\n\x08vxrs_low\x18\x04 \x01(\x0b\x32\x19.user_s390_vxrs_low_entryB\x05\xd2?\x02\x08\x01\x12\x34\n\tvxrs_high\x18\x05 \x01(\x0b\x32\x1a.user_s390_vxrs_high_entryB\x05\xd2?\x02\x08\x01\x12,\n\x05gs_cb\x18\x06 \x01(\x0b\x32\x16.user_s390_gs_cb_entryB\x05\xd2?\x02\x08\x01\x12,\n\x05gs_bc\x18\x07 \x01(\x0b\x32\x16.user_s390_gs_cb_entryB\x05\xd2?\x02\x08\x01\x12)\n\x05ri_cb\x18\x08 \x01(\x0b\x32\x13.user_s390_ri_entryB\x05\xd2?\x02\x08\x01')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_USER_S390_REGS_ENTRY = _descriptor.Descriptor(
  name='user_s390_regs_entry',
  full_name='user_s390_regs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='psw_mask', full_name='user_s390_regs_entry.psw_mask', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='psw_addr', full_name='user_s390_regs_entry.psw_addr', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gprs', full_name='user_s390_regs_entry.gprs', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acrs', full_name='user_s390_regs_entry.acrs', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orig_gpr2', full_name='user_s390_regs_entry.orig_gpr2', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_call', full_name='user_s390_regs_entry.system_call', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=157,
)


_USER_S390_VXRS_LOW_ENTRY = _descriptor.Descriptor(
  name='user_s390_vxrs_low_entry',
  full_name='user_s390_vxrs_low_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regs', full_name='user_s390_vxrs_low_entry.regs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=199,
)


_USER_S390_VXRS_HIGH_ENTRY = _descriptor.Descriptor(
  name='user_s390_vxrs_high_entry',
  full_name='user_s390_vxrs_high_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regs', full_name='user_s390_vxrs_high_entry.regs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=242,
)


_USER_S390_FPREGS_ENTRY = _descriptor.Descriptor(
  name='user_s390_fpregs_entry',
  full_name='user_s390_fpregs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fpc', full_name='user_s390_fpregs_entry.fpc', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fprs', full_name='user_s390_fpregs_entry.fprs', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=295,
)


_USER_S390_GS_CB_ENTRY = _descriptor.Descriptor(
  name='user_s390_gs_cb_entry',
  full_name='user_s390_gs_cb_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regs', full_name='user_s390_gs_cb_entry.regs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=334,
)


_USER_S390_RI_ENTRY = _descriptor.Descriptor(
  name='user_s390_ri_entry',
  full_name='user_s390_ri_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ri_on', full_name='user_s390_ri_entry.ri_on', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regs', full_name='user_s390_ri_entry.regs', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=385,
)


_THREAD_INFO_S390 = _descriptor.Descriptor(
  name='thread_info_s390',
  full_name='thread_info_s390',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear_tid_addr', full_name='thread_info_s390.clear_tid_addr', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpregs', full_name='thread_info_s390.gpregs', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpregs', full_name='thread_info_s390.fpregs', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vxrs_low', full_name='thread_info_s390.vxrs_low', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vxrs_high', full_name='thread_info_s390.vxrs_high', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gs_cb', full_name='thread_info_s390.gs_cb', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gs_bc', full_name='thread_info_s390.gs_bc', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ri_cb', full_name='thread_info_s390.ri_cb', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=388,
  serialized_end=772,
)

_THREAD_INFO_S390.fields_by_name['gpregs'].message_type = _USER_S390_REGS_ENTRY
_THREAD_INFO_S390.fields_by_name['fpregs'].message_type = _USER_S390_FPREGS_ENTRY
_THREAD_INFO_S390.fields_by_name['vxrs_low'].message_type = _USER_S390_VXRS_LOW_ENTRY
_THREAD_INFO_S390.fields_by_name['vxrs_high'].message_type = _USER_S390_VXRS_HIGH_ENTRY
_THREAD_INFO_S390.fields_by_name['gs_cb'].message_type = _USER_S390_GS_CB_ENTRY
_THREAD_INFO_S390.fields_by_name['gs_bc'].message_type = _USER_S390_GS_CB_ENTRY
_THREAD_INFO_S390.fields_by_name['ri_cb'].message_type = _USER_S390_RI_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_regs_entry'] = _USER_S390_REGS_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_vxrs_low_entry'] = _USER_S390_VXRS_LOW_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_vxrs_high_entry'] = _USER_S390_VXRS_HIGH_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_fpregs_entry'] = _USER_S390_FPREGS_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_gs_cb_entry'] = _USER_S390_GS_CB_ENTRY
DESCRIPTOR.message_types_by_name['user_s390_ri_entry'] = _USER_S390_RI_ENTRY
DESCRIPTOR.message_types_by_name['thread_info_s390'] = _THREAD_INFO_S390
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

user_s390_regs_entry = _reflection.GeneratedProtocolMessageType('user_s390_regs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_REGS_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_regs_entry)
  ))
_sym_db.RegisterMessage(user_s390_regs_entry)

user_s390_vxrs_low_entry = _reflection.GeneratedProtocolMessageType('user_s390_vxrs_low_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_VXRS_LOW_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_vxrs_low_entry)
  ))
_sym_db.RegisterMessage(user_s390_vxrs_low_entry)

user_s390_vxrs_high_entry = _reflection.GeneratedProtocolMessageType('user_s390_vxrs_high_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_VXRS_HIGH_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_vxrs_high_entry)
  ))
_sym_db.RegisterMessage(user_s390_vxrs_high_entry)

user_s390_fpregs_entry = _reflection.GeneratedProtocolMessageType('user_s390_fpregs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_FPREGS_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_fpregs_entry)
  ))
_sym_db.RegisterMessage(user_s390_fpregs_entry)

user_s390_gs_cb_entry = _reflection.GeneratedProtocolMessageType('user_s390_gs_cb_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_GS_CB_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_gs_cb_entry)
  ))
_sym_db.RegisterMessage(user_s390_gs_cb_entry)

user_s390_ri_entry = _reflection.GeneratedProtocolMessageType('user_s390_ri_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_S390_RI_ENTRY,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:user_s390_ri_entry)
  ))
_sym_db.RegisterMessage(user_s390_ri_entry)

thread_info_s390 = _reflection.GeneratedProtocolMessageType('thread_info_s390', (_message.Message,), dict(
  DESCRIPTOR = _THREAD_INFO_S390,
  __module__ = 'core_s390_pb2'
  # @@protoc_insertion_point(class_scope:thread_info_s390)
  ))
_sym_db.RegisterMessage(thread_info_s390)


_THREAD_INFO_S390.fields_by_name['clear_tid_addr'].has_options = True
_THREAD_INFO_S390.fields_by_name['clear_tid_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['gpregs'].has_options = True
_THREAD_INFO_S390.fields_by_name['gpregs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['fpregs'].has_options = True
_THREAD_INFO_S390.fields_by_name['fpregs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['vxrs_low'].has_options = True
_THREAD_INFO_S390.fields_by_name['vxrs_low']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['vxrs_high'].has_options = True
_THREAD_INFO_S390.fields_by_name['vxrs_high']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['gs_cb'].has_options = True
_THREAD_INFO_S390.fields_by_name['gs_cb']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['gs_bc'].has_options = True
_THREAD_INFO_S390.fields_by_name['gs_bc']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_S390.fields_by_name['ri_cb'].has_options = True
_THREAD_INFO_S390.fields_by_name['ri_cb']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)
