# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sit.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\tsit.proto\x1a\nopts.proto\"\xc9\x02\n\tsit_entry\x12\x0c\n\x04link\x18\x01 \x01(\r\x12\x14\n\x05local\x18\x02 \x03(\rB\x05\xd2?\x02\x10\x01\x12\x15\n\x06remote\x18\x03 \x03(\rB\x05\xd2?\x02\x10\x01\x12\x0b\n\x03ttl\x18\x04 \x01(\r\x12\x0b\n\x03tos\x18\x05 \x01(\r\x12\x10\n\x08pmtudisc\x18\x06 \x01(\x08\x12\r\n\x05proto\x18\x07 \x01(\r\x12\r\n\x05\x66lags\x18\x08 \x01(\r\x12\x12\n\nencap_type\x18\t \x01(\r\x12\x13\n\x0b\x65ncap_flags\x18\n \x01(\r\x12\x13\n\x0b\x65ncap_sport\x18\x0b \x01(\r\x12\x13\n\x0b\x65ncap_dport\x18\x0c \x01(\r\x12\x14\n\x0crd_prefixlen\x18\r \x01(\r\x12\x18\n\trd_prefix\x18\x0e \x03(\rB\x05\xd2?\x02\x10\x01\x12\x17\n\x0frelay_prefixlen\x18\x0f \x01(\r\x12\x1b\n\x0crelay_prefix\x18\x10 \x03(\rB\x05\xd2?\x02\x10\x01')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_SIT_ENTRY = _descriptor.Descriptor(
  name='sit_entry',
  full_name='sit_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='sit_entry.link', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local', full_name='sit_entry.local', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote', full_name='sit_entry.remote', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='sit_entry.ttl', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tos', full_name='sit_entry.tos', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pmtudisc', full_name='sit_entry.pmtudisc', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proto', full_name='sit_entry.proto', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='sit_entry.flags', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encap_type', full_name='sit_entry.encap_type', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encap_flags', full_name='sit_entry.encap_flags', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encap_sport', full_name='sit_entry.encap_sport', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encap_dport', full_name='sit_entry.encap_dport', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rd_prefixlen', full_name='sit_entry.rd_prefixlen', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rd_prefix', full_name='sit_entry.rd_prefix', index=13,
      number=14, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relay_prefixlen', full_name='sit_entry.relay_prefixlen', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relay_prefix', full_name='sit_entry.relay_prefix', index=15,
      number=16, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=355,
)

DESCRIPTOR.message_types_by_name['sit_entry'] = _SIT_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

sit_entry = _reflection.GeneratedProtocolMessageType('sit_entry', (_message.Message,), dict(
  DESCRIPTOR = _SIT_ENTRY,
  __module__ = 'sit_pb2'
  # @@protoc_insertion_point(class_scope:sit_entry)
  ))
_sym_db.RegisterMessage(sit_entry)


_SIT_ENTRY.fields_by_name['local'].has_options = True
_SIT_ENTRY.fields_by_name['local']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
_SIT_ENTRY.fields_by_name['remote'].has_options = True
_SIT_ENTRY.fields_by_name['remote']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
_SIT_ENTRY.fields_by_name['rd_prefix'].has_options = True
_SIT_ENTRY.fields_by_name['rd_prefix']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
_SIT_ENTRY.fields_by_name['relay_prefix'].has_options = True
_SIT_ENTRY.fields_by_name['relay_prefix']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\020\001'))
# @@protoc_insertion_point(module_scope)
