# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sk-packet.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sk-packet.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0fsk-packet.proto\")\n\tscm_entry\x12\x0c\n\x04type\x18\x01 \x02(\r\x12\x0e\n\x06rights\x18\x02 \x03(\r\"J\n\x0fsk_packet_entry\x12\x0e\n\x06id_for\x18\x01 \x02(\r\x12\x0e\n\x06length\x18\x02 \x02(\r\x12\x17\n\x03scm\x18\x04 \x03(\x0b\x32\n.scm_entry')
)




_SCM_ENTRY = _descriptor.Descriptor(
  name='scm_entry',
  full_name='scm_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='scm_entry.type', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rights', full_name='scm_entry.rights', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19,
  serialized_end=60,
)


_SK_PACKET_ENTRY = _descriptor.Descriptor(
  name='sk_packet_entry',
  full_name='sk_packet_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_for', full_name='sk_packet_entry.id_for', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='sk_packet_entry.length', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scm', full_name='sk_packet_entry.scm', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=136,
)

_SK_PACKET_ENTRY.fields_by_name['scm'].message_type = _SCM_ENTRY
DESCRIPTOR.message_types_by_name['scm_entry'] = _SCM_ENTRY
DESCRIPTOR.message_types_by_name['sk_packet_entry'] = _SK_PACKET_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

scm_entry = _reflection.GeneratedProtocolMessageType('scm_entry', (_message.Message,), dict(
  DESCRIPTOR = _SCM_ENTRY,
  __module__ = 'sk_packet_pb2'
  # @@protoc_insertion_point(class_scope:scm_entry)
  ))
_sym_db.RegisterMessage(scm_entry)

sk_packet_entry = _reflection.GeneratedProtocolMessageType('sk_packet_entry', (_message.Message,), dict(
  DESCRIPTOR = _SK_PACKET_ENTRY,
  __module__ = 'sk_packet_pb2'
  # @@protoc_insertion_point(class_scope:sk_packet_entry)
  ))
_sym_db.RegisterMessage(sk_packet_entry)


# @@protoc_insertion_point(module_scope)
