# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sa.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sa.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x08sa.proto\x1a\nopts.proto\"\x82\x01\n\x08sa_entry\x12\x18\n\tsigaction\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x14\n\x05\x66lags\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x17\n\x08restorer\x18\x03 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x13\n\x04mask\x18\x04 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x18\n\x10\x63ompat_sigaction\x18\x05 \x01(\x08')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_SA_ENTRY = _descriptor.Descriptor(
  name='sa_entry',
  full_name='sa_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sigaction', full_name='sa_entry.sigaction', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='sa_entry.flags', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restorer', full_name='sa_entry.restorer', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='sa_entry.mask', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compat_sigaction', full_name='sa_entry.compat_sigaction', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=155,
)

DESCRIPTOR.message_types_by_name['sa_entry'] = _SA_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

sa_entry = _reflection.GeneratedProtocolMessageType('sa_entry', (_message.Message,), dict(
  DESCRIPTOR = _SA_ENTRY,
  __module__ = 'sa_pb2'
  # @@protoc_insertion_point(class_scope:sa_entry)
  ))
_sym_db.RegisterMessage(sa_entry)


_SA_ENTRY.fields_by_name['sigaction'].has_options = True
_SA_ENTRY.fields_by_name['sigaction']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_SA_ENTRY.fields_by_name['flags'].has_options = True
_SA_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_SA_ENTRY.fields_by_name['restorer'].has_options = True
_SA_ENTRY.fields_by_name['restorer']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_SA_ENTRY.fields_by_name['mask'].has_options = True
_SA_ENTRY.fields_by_name['mask']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)
