# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tun.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tun.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\ttun.proto\x1a\nopts.proto\"L\n\rtunfile_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0e\n\x06netdev\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65tached\x18\x03 \x01(\x08\x12\r\n\x05ns_id\x18\x04 \x01(\r\"e\n\x0etun_link_entry\x12\x14\n\x05\x66lags\x18\x01 \x02(\rB\x05\xd2?\x02\x08\x01\x12\r\n\x05owner\x18\x02 \x02(\x05\x12\r\n\x05group\x18\x03 \x02(\x05\x12\x0f\n\x07vnethdr\x18\x04 \x02(\r\x12\x0e\n\x06sndbuf\x18\x05 \x02(\r')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_TUNFILE_ENTRY = _descriptor.Descriptor(
  name='tunfile_entry',
  full_name='tunfile_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='tunfile_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='netdev', full_name='tunfile_entry.netdev', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detached', full_name='tunfile_entry.detached', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_id', full_name='tunfile_entry.ns_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=101,
)


_TUN_LINK_ENTRY = _descriptor.Descriptor(
  name='tun_link_entry',
  full_name='tun_link_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='tun_link_entry.flags', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='tun_link_entry.owner', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='tun_link_entry.group', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vnethdr', full_name='tun_link_entry.vnethdr', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sndbuf', full_name='tun_link_entry.sndbuf', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=204,
)

DESCRIPTOR.message_types_by_name['tunfile_entry'] = _TUNFILE_ENTRY
DESCRIPTOR.message_types_by_name['tun_link_entry'] = _TUN_LINK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

tunfile_entry = _reflection.GeneratedProtocolMessageType('tunfile_entry', (_message.Message,), dict(
  DESCRIPTOR = _TUNFILE_ENTRY,
  __module__ = 'tun_pb2'
  # @@protoc_insertion_point(class_scope:tunfile_entry)
  ))
_sym_db.RegisterMessage(tunfile_entry)

tun_link_entry = _reflection.GeneratedProtocolMessageType('tun_link_entry', (_message.Message,), dict(
  DESCRIPTOR = _TUN_LINK_ENTRY,
  __module__ = 'tun_pb2'
  # @@protoc_insertion_point(class_scope:tun_link_entry)
  ))
_sym_db.RegisterMessage(tun_link_entry)


_TUN_LINK_ENTRY.fields_by_name['flags'].has_options = True
_TUN_LINK_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)
