# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vma.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='vma.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\tvma.proto\x1a\nopts.proto\"\xfe\x01\n\tvma_entry\x12\x14\n\x05start\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x12\n\x03\x65nd\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\r\n\x05pgoff\x18\x03 \x02(\x04\x12\r\n\x05shmid\x18\x04 \x02(\x04\x12\x1c\n\x04prot\x18\x05 \x02(\rB\x0e\xd2?\x0b\x1a\tmmap.prot\x12\x1e\n\x05\x66lags\x18\x06 \x02(\rB\x0f\xd2?\x0c\x1a\nmmap.flags\x12 \n\x06status\x18\x07 \x02(\rB\x10\xd2?\r\x1a\x0bmmap.status\x12\n\n\x02\x66\x64\x18\x08 \x02(\x12\x12\x13\n\x04madv\x18\t \x01(\x04\x42\x05\xd2?\x02\x08\x01\x12\x16\n\x07\x66\x64\x66lags\x18\n \x01(\rB\x05\xd2?\x02\x08\x01\x12\x10\n\x08out_jail\x18\x0b \x01(\x08')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_VMA_ENTRY = _descriptor.Descriptor(
  name='vma_entry',
  full_name='vma_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='vma_entry.start', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='vma_entry.end', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pgoff', full_name='vma_entry.pgoff', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shmid', full_name='vma_entry.shmid', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prot', full_name='vma_entry.prot', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\013\032\tmmap.prot')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='vma_entry.flags', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\014\032\nmmap.flags')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='vma_entry.status', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\r\032\013mmap.status')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fd', full_name='vma_entry.fd', index=7,
      number=8, type=18, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='madv', full_name='vma_entry.madv', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fdflags', full_name='vma_entry.fdflags', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_jail', full_name='vma_entry.out_jail', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=280,
)

DESCRIPTOR.message_types_by_name['vma_entry'] = _VMA_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

vma_entry = _reflection.GeneratedProtocolMessageType('vma_entry', (_message.Message,), dict(
  DESCRIPTOR = _VMA_ENTRY,
  __module__ = 'vma_pb2'
  # @@protoc_insertion_point(class_scope:vma_entry)
  ))
_sym_db.RegisterMessage(vma_entry)


_VMA_ENTRY.fields_by_name['start'].has_options = True
_VMA_ENTRY.fields_by_name['start']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_VMA_ENTRY.fields_by_name['end'].has_options = True
_VMA_ENTRY.fields_by_name['end']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_VMA_ENTRY.fields_by_name['prot'].has_options = True
_VMA_ENTRY.fields_by_name['prot']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\013\032\tmmap.prot'))
_VMA_ENTRY.fields_by_name['flags'].has_options = True
_VMA_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\014\032\nmmap.flags'))
_VMA_ENTRY.fields_by_name['status'].has_options = True
_VMA_ENTRY.fields_by_name['status']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\r\032\013mmap.status'))
_VMA_ENTRY.fields_by_name['madv'].has_options = True
_VMA_ENTRY.fields_by_name['madv']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_VMA_ENTRY.fields_by_name['fdflags'].has_options = True
_VMA_ENTRY.fields_by_name['fdflags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)
