# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core-x86.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core-x86.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0e\x63ore-x86.proto\x1a\nopts.proto\"\x9c\x03\n\x13user_x86_regs_entry\x12\x0b\n\x03r15\x18\x01 \x02(\x04\x12\x0b\n\x03r14\x18\x02 \x02(\x04\x12\x0b\n\x03r13\x18\x03 \x02(\x04\x12\x0b\n\x03r12\x18\x04 \x02(\x04\x12\n\n\x02\x62p\x18\x05 \x02(\x04\x12\n\n\x02\x62x\x18\x06 \x02(\x04\x12\x0b\n\x03r11\x18\x07 \x02(\x04\x12\x0b\n\x03r10\x18\x08 \x02(\x04\x12\n\n\x02r9\x18\t \x02(\x04\x12\n\n\x02r8\x18\n \x02(\x04\x12\n\n\x02\x61x\x18\x0b \x02(\x04\x12\n\n\x02\x63x\x18\x0c \x02(\x04\x12\n\n\x02\x64x\x18\r \x02(\x04\x12\n\n\x02si\x18\x0e \x02(\x04\x12\n\n\x02\x64i\x18\x0f \x02(\x04\x12\x0f\n\x07orig_ax\x18\x10 \x02(\x04\x12\n\n\x02ip\x18\x11 \x02(\x04\x12\n\n\x02\x63s\x18\x12 \x02(\x04\x12\r\n\x05\x66lags\x18\x13 \x02(\x04\x12\n\n\x02sp\x18\x14 \x02(\x04\x12\n\n\x02ss\x18\x15 \x02(\x04\x12\x0f\n\x07\x66s_base\x18\x16 \x02(\x04\x12\x0f\n\x07gs_base\x18\x17 \x02(\x04\x12\n\n\x02\x64s\x18\x18 \x02(\x04\x12\n\n\x02\x65s\x18\x19 \x02(\x04\x12\n\n\x02\x66s\x18\x1a \x02(\x04\x12\n\n\x02gs\x18\x1b \x02(\x04\x12)\n\x04mode\x18\x1c \x01(\x0e\x32\x13.user_x86_regs_mode:\x06NATIVE\"\xb0\x01\n\x14user_x86_xsave_entry\x12\x11\n\txstate_bv\x18\x01 \x02(\x04\x12\x12\n\nymmh_space\x18\x02 \x03(\r\x12\x14\n\x0c\x62ndreg_state\x18\x03 \x03(\x04\x12\x14\n\x0c\x62ndcsr_state\x18\x04 \x03(\x04\x12\x12\n\nopmask_reg\x18\x05 \x03(\x04\x12\x11\n\tzmm_upper\x18\x06 \x03(\x04\x12\x10\n\x08hi16_zmm\x18\x07 \x03(\x04\x12\x0c\n\x04pkru\x18\x08 \x03(\r\"\xe4\x01\n\x15user_x86_fpregs_entry\x12\x0b\n\x03\x63wd\x18\x01 \x02(\r\x12\x0b\n\x03swd\x18\x02 \x02(\r\x12\x0b\n\x03twd\x18\x03 \x02(\r\x12\x0b\n\x03\x66op\x18\x04 \x02(\r\x12\x0b\n\x03rip\x18\x05 \x02(\x04\x12\x0b\n\x03rdp\x18\x06 \x02(\x04\x12\r\n\x05mxcsr\x18\x07 \x02(\r\x12\x12\n\nmxcsr_mask\x18\x08 \x02(\r\x12\x10\n\x08st_space\x18\t \x03(\r\x12\x11\n\txmm_space\x18\n \x03(\r\x12\x0f\n\x07padding\x18\x0b \x03(\r\x12$\n\x05xsave\x18\r \x01(\x0b\x32\x15.user_x86_xsave_entry\"\xe6\x01\n\x0buser_desc_t\x12\x14\n\x0c\x65ntry_number\x18\x01 \x02(\r\x12\x11\n\tbase_addr\x18\x02 \x02(\r\x12\r\n\x05limit\x18\x03 \x02(\r\x12\x11\n\tseg_32bit\x18\x04 \x02(\x08\x12\x12\n\ncontents_h\x18\x05 \x02(\x08\x12\x12\n\ncontents_l\x18\x06 \x02(\x08\x12\x1c\n\x0eread_exec_only\x18\x07 \x02(\x08:\x04true\x12\x16\n\x0elimit_in_pages\x18\x08 \x02(\x08\x12\x1d\n\x0fseg_not_present\x18\t \x02(\x08:\x04true\x12\x0f\n\x07useable\x18\n \x02(\x08\"\xa0\x01\n\x0fthread_info_x86\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12+\n\x06gpregs\x18\x02 \x02(\x0b\x32\x14.user_x86_regs_entryB\x05\xd2?\x02\x08\x01\x12&\n\x06\x66pregs\x18\x03 \x02(\x0b\x32\x16.user_x86_fpregs_entry\x12\x19\n\x03tls\x18\x04 \x03(\x0b\x32\x0c.user_desc_t*,\n\x12user_x86_regs_mode\x12\n\n\x06NATIVE\x10\x01\x12\n\n\x06\x43OMPAT\x10\x02')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])

_USER_X86_REGS_MODE = _descriptor.EnumDescriptor(
  name='user_x86_regs_mode',
  full_name='user_x86_regs_mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NATIVE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPAT', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1251,
  serialized_end=1295,
)
_sym_db.RegisterEnumDescriptor(_USER_X86_REGS_MODE)

user_x86_regs_mode = enum_type_wrapper.EnumTypeWrapper(_USER_X86_REGS_MODE)
NATIVE = 1
COMPAT = 2



_USER_X86_REGS_ENTRY = _descriptor.Descriptor(
  name='user_x86_regs_entry',
  full_name='user_x86_regs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='r15', full_name='user_x86_regs_entry.r15', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r14', full_name='user_x86_regs_entry.r14', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r13', full_name='user_x86_regs_entry.r13', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r12', full_name='user_x86_regs_entry.r12', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bp', full_name='user_x86_regs_entry.bp', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bx', full_name='user_x86_regs_entry.bx', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r11', full_name='user_x86_regs_entry.r11', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r10', full_name='user_x86_regs_entry.r10', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r9', full_name='user_x86_regs_entry.r9', index=8,
      number=9, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r8', full_name='user_x86_regs_entry.r8', index=9,
      number=10, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ax', full_name='user_x86_regs_entry.ax', index=10,
      number=11, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cx', full_name='user_x86_regs_entry.cx', index=11,
      number=12, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dx', full_name='user_x86_regs_entry.dx', index=12,
      number=13, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='si', full_name='user_x86_regs_entry.si', index=13,
      number=14, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='di', full_name='user_x86_regs_entry.di', index=14,
      number=15, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orig_ax', full_name='user_x86_regs_entry.orig_ax', index=15,
      number=16, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip', full_name='user_x86_regs_entry.ip', index=16,
      number=17, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cs', full_name='user_x86_regs_entry.cs', index=17,
      number=18, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='user_x86_regs_entry.flags', index=18,
      number=19, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sp', full_name='user_x86_regs_entry.sp', index=19,
      number=20, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ss', full_name='user_x86_regs_entry.ss', index=20,
      number=21, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fs_base', full_name='user_x86_regs_entry.fs_base', index=21,
      number=22, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gs_base', full_name='user_x86_regs_entry.gs_base', index=22,
      number=23, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ds', full_name='user_x86_regs_entry.ds', index=23,
      number=24, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='es', full_name='user_x86_regs_entry.es', index=24,
      number=25, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fs', full_name='user_x86_regs_entry.fs', index=25,
      number=26, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gs', full_name='user_x86_regs_entry.gs', index=26,
      number=27, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='user_x86_regs_entry.mode', index=27,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=443,
)


_USER_X86_XSAVE_ENTRY = _descriptor.Descriptor(
  name='user_x86_xsave_entry',
  full_name='user_x86_xsave_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='xstate_bv', full_name='user_x86_xsave_entry.xstate_bv', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ymmh_space', full_name='user_x86_xsave_entry.ymmh_space', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bndreg_state', full_name='user_x86_xsave_entry.bndreg_state', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bndcsr_state', full_name='user_x86_xsave_entry.bndcsr_state', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opmask_reg', full_name='user_x86_xsave_entry.opmask_reg', index=4,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zmm_upper', full_name='user_x86_xsave_entry.zmm_upper', index=5,
      number=6, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hi16_zmm', full_name='user_x86_xsave_entry.hi16_zmm', index=6,
      number=7, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkru', full_name='user_x86_xsave_entry.pkru', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=622,
)


_USER_X86_FPREGS_ENTRY = _descriptor.Descriptor(
  name='user_x86_fpregs_entry',
  full_name='user_x86_fpregs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cwd', full_name='user_x86_fpregs_entry.cwd', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swd', full_name='user_x86_fpregs_entry.swd', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='twd', full_name='user_x86_fpregs_entry.twd', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fop', full_name='user_x86_fpregs_entry.fop', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rip', full_name='user_x86_fpregs_entry.rip', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rdp', full_name='user_x86_fpregs_entry.rdp', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mxcsr', full_name='user_x86_fpregs_entry.mxcsr', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mxcsr_mask', full_name='user_x86_fpregs_entry.mxcsr_mask', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='st_space', full_name='user_x86_fpregs_entry.st_space', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xmm_space', full_name='user_x86_fpregs_entry.xmm_space', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding', full_name='user_x86_fpregs_entry.padding', index=10,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xsave', full_name='user_x86_fpregs_entry.xsave', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=853,
)


_USER_DESC_T = _descriptor.Descriptor(
  name='user_desc_t',
  full_name='user_desc_t',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry_number', full_name='user_desc_t.entry_number', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_addr', full_name='user_desc_t.base_addr', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='user_desc_t.limit', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seg_32bit', full_name='user_desc_t.seg_32bit', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contents_h', full_name='user_desc_t.contents_h', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contents_l', full_name='user_desc_t.contents_l', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_exec_only', full_name='user_desc_t.read_exec_only', index=6,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit_in_pages', full_name='user_desc_t.limit_in_pages', index=7,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seg_not_present', full_name='user_desc_t.seg_not_present', index=8,
      number=9, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useable', full_name='user_desc_t.useable', index=9,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=1086,
)


_THREAD_INFO_X86 = _descriptor.Descriptor(
  name='thread_info_x86',
  full_name='thread_info_x86',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear_tid_addr', full_name='thread_info_x86.clear_tid_addr', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpregs', full_name='thread_info_x86.gpregs', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpregs', full_name='thread_info_x86.fpregs', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls', full_name='thread_info_x86.tls', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1249,
)

_USER_X86_REGS_ENTRY.fields_by_name['mode'].enum_type = _USER_X86_REGS_MODE
_USER_X86_FPREGS_ENTRY.fields_by_name['xsave'].message_type = _USER_X86_XSAVE_ENTRY
_THREAD_INFO_X86.fields_by_name['gpregs'].message_type = _USER_X86_REGS_ENTRY
_THREAD_INFO_X86.fields_by_name['fpregs'].message_type = _USER_X86_FPREGS_ENTRY
_THREAD_INFO_X86.fields_by_name['tls'].message_type = _USER_DESC_T
DESCRIPTOR.message_types_by_name['user_x86_regs_entry'] = _USER_X86_REGS_ENTRY
DESCRIPTOR.message_types_by_name['user_x86_xsave_entry'] = _USER_X86_XSAVE_ENTRY
DESCRIPTOR.message_types_by_name['user_x86_fpregs_entry'] = _USER_X86_FPREGS_ENTRY
DESCRIPTOR.message_types_by_name['user_desc_t'] = _USER_DESC_T
DESCRIPTOR.message_types_by_name['thread_info_x86'] = _THREAD_INFO_X86
DESCRIPTOR.enum_types_by_name['user_x86_regs_mode'] = _USER_X86_REGS_MODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

user_x86_regs_entry = _reflection.GeneratedProtocolMessageType('user_x86_regs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_X86_REGS_ENTRY,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:user_x86_regs_entry)
  ))
_sym_db.RegisterMessage(user_x86_regs_entry)

user_x86_xsave_entry = _reflection.GeneratedProtocolMessageType('user_x86_xsave_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_X86_XSAVE_ENTRY,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:user_x86_xsave_entry)
  ))
_sym_db.RegisterMessage(user_x86_xsave_entry)

user_x86_fpregs_entry = _reflection.GeneratedProtocolMessageType('user_x86_fpregs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_X86_FPREGS_ENTRY,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:user_x86_fpregs_entry)
  ))
_sym_db.RegisterMessage(user_x86_fpregs_entry)

user_desc_t = _reflection.GeneratedProtocolMessageType('user_desc_t', (_message.Message,), dict(
  DESCRIPTOR = _USER_DESC_T,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:user_desc_t)
  ))
_sym_db.RegisterMessage(user_desc_t)

thread_info_x86 = _reflection.GeneratedProtocolMessageType('thread_info_x86', (_message.Message,), dict(
  DESCRIPTOR = _THREAD_INFO_X86,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:thread_info_x86)
  ))
_sym_db.RegisterMessage(thread_info_x86)


_THREAD_INFO_X86.fields_by_name['clear_tid_addr'].has_options = True
_THREAD_INFO_X86.fields_by_name['clear_tid_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_X86.fields_by_name['gpregs'].has_options = True
_THREAD_INFO_X86.fields_by_name['gpregs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)
