# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tcp-stream.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tcp-stream.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x10tcp-stream.proto\x1a\nopts.proto\"\xc8\x02\n\x10tcp_stream_entry\x12\x0f\n\x07inq_len\x18\x01 \x02(\r\x12\x0f\n\x07inq_seq\x18\x02 \x02(\r\x12\x10\n\x08outq_len\x18\x03 \x02(\r\x12\x10\n\x08outq_seq\x18\x04 \x02(\r\x12\x17\n\x08opt_mask\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x12\n\nsnd_wscale\x18\x06 \x02(\r\x12\x11\n\tmss_clamp\x18\x07 \x02(\r\x12\x12\n\nrcv_wscale\x18\x08 \x01(\r\x12\x11\n\ttimestamp\x18\t \x01(\r\x12\x0c\n\x04\x63ork\x18\n \x01(\x08\x12\x0f\n\x07nodelay\x18\x0b \x01(\x08\x12\x10\n\x08unsq_len\x18\x0c \x01(\r\x12\x0f\n\x07snd_wl1\x18\r \x01(\r\x12\x0f\n\x07snd_wnd\x18\x0e \x01(\r\x12\x12\n\nmax_window\x18\x0f \x01(\r\x12\x0f\n\x07rcv_wnd\x18\x10 \x01(\r\x12\x0f\n\x07rcv_wup\x18\x11 \x01(\r')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_TCP_STREAM_ENTRY = _descriptor.Descriptor(
  name='tcp_stream_entry',
  full_name='tcp_stream_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inq_len', full_name='tcp_stream_entry.inq_len', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inq_seq', full_name='tcp_stream_entry.inq_seq', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outq_len', full_name='tcp_stream_entry.outq_len', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outq_seq', full_name='tcp_stream_entry.outq_seq', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opt_mask', full_name='tcp_stream_entry.opt_mask', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snd_wscale', full_name='tcp_stream_entry.snd_wscale', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mss_clamp', full_name='tcp_stream_entry.mss_clamp', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rcv_wscale', full_name='tcp_stream_entry.rcv_wscale', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tcp_stream_entry.timestamp', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cork', full_name='tcp_stream_entry.cork', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodelay', full_name='tcp_stream_entry.nodelay', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsq_len', full_name='tcp_stream_entry.unsq_len', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snd_wl1', full_name='tcp_stream_entry.snd_wl1', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snd_wnd', full_name='tcp_stream_entry.snd_wnd', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_window', full_name='tcp_stream_entry.max_window', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rcv_wnd', full_name='tcp_stream_entry.rcv_wnd', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rcv_wup', full_name='tcp_stream_entry.rcv_wup', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=361,
)

DESCRIPTOR.message_types_by_name['tcp_stream_entry'] = _TCP_STREAM_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

tcp_stream_entry = _reflection.GeneratedProtocolMessageType('tcp_stream_entry', (_message.Message,), dict(
  DESCRIPTOR = _TCP_STREAM_ENTRY,
  __module__ = 'tcp_stream_pb2'
  # @@protoc_insertion_point(class_scope:tcp_stream_entry)
  ))
_sym_db.RegisterMessage(tcp_stream_entry)


_TCP_STREAM_ENTRY.fields_by_name['opt_mask'].has_options = True
_TCP_STREAM_ENTRY.fields_by_name['opt_mask']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)
