# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cpuinfo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cpuinfo.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\rcpuinfo.proto\"\xa3\x02\n\x11\x63puinfo_x86_entry\x12,\n\tvendor_id\x18\x01 \x02(\x0e\x32\x19.cpuinfo_x86_entry.vendor\x12\x12\n\ncpu_family\x18\x02 \x02(\r\x12\r\n\x05model\x18\x03 \x02(\r\x12\x10\n\x08stepping\x18\x04 \x02(\r\x12\x16\n\x0e\x63\x61pability_ver\x18\x05 \x02(\r\x12\x12\n\ncapability\x18\x06 \x03(\r\x12\x10\n\x08model_id\x18\x07 \x01(\t\x12\x16\n\x0exfeatures_mask\x18\x08 \x01(\x04\x12\x12\n\nxsave_size\x18\t \x01(\r\x12\x16\n\x0exsave_size_max\x18\n \x01(\r\")\n\x06vendor\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05INTEL\x10\x01\x12\x07\n\x03\x41MD\x10\x02\"\x84\x01\n\x13\x63puinfo_ppc64_entry\x12/\n\x06\x65ndian\x18\x01 \x02(\x0e\x32\x1f.cpuinfo_ppc64_entry.endianness\x12\r\n\x05hwcap\x18\x02 \x03(\x04\"-\n\nendianness\x12\r\n\tBIGENDIAN\x10\x00\x12\x10\n\x0cLITTLEENDIAN\x10\x01\"#\n\x12\x63puinfo_s390_entry\x12\r\n\x05hwcap\x18\x02 \x03(\x04\"\x8a\x01\n\rcpuinfo_entry\x12%\n\tx86_entry\x18\x01 \x03(\x0b\x32\x12.cpuinfo_x86_entry\x12)\n\x0bppc64_entry\x18\x02 \x03(\x0b\x32\x14.cpuinfo_ppc64_entry\x12\'\n\ns390_entry\x18\x03 \x03(\x0b\x32\x13.cpuinfo_s390_entry')
)



_CPUINFO_X86_ENTRY_VENDOR = _descriptor.EnumDescriptor(
  name='vendor',
  full_name='cpuinfo_x86_entry.vendor',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AMD', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=268,
  serialized_end=309,
)
_sym_db.RegisterEnumDescriptor(_CPUINFO_X86_ENTRY_VENDOR)

_CPUINFO_PPC64_ENTRY_ENDIANNESS = _descriptor.EnumDescriptor(
  name='endianness',
  full_name='cpuinfo_ppc64_entry.endianness',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BIGENDIAN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LITTLEENDIAN', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=399,
  serialized_end=444,
)
_sym_db.RegisterEnumDescriptor(_CPUINFO_PPC64_ENTRY_ENDIANNESS)


_CPUINFO_X86_ENTRY = _descriptor.Descriptor(
  name='cpuinfo_x86_entry',
  full_name='cpuinfo_x86_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor_id', full_name='cpuinfo_x86_entry.vendor_id', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_family', full_name='cpuinfo_x86_entry.cpu_family', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='cpuinfo_x86_entry.model', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepping', full_name='cpuinfo_x86_entry.stepping', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capability_ver', full_name='cpuinfo_x86_entry.capability_ver', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capability', full_name='cpuinfo_x86_entry.capability', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cpuinfo_x86_entry.model_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xfeatures_mask', full_name='cpuinfo_x86_entry.xfeatures_mask', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xsave_size', full_name='cpuinfo_x86_entry.xsave_size', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xsave_size_max', full_name='cpuinfo_x86_entry.xsave_size_max', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CPUINFO_X86_ENTRY_VENDOR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=309,
)


_CPUINFO_PPC64_ENTRY = _descriptor.Descriptor(
  name='cpuinfo_ppc64_entry',
  full_name='cpuinfo_ppc64_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endian', full_name='cpuinfo_ppc64_entry.endian', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hwcap', full_name='cpuinfo_ppc64_entry.hwcap', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CPUINFO_PPC64_ENTRY_ENDIANNESS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=444,
)


_CPUINFO_S390_ENTRY = _descriptor.Descriptor(
  name='cpuinfo_s390_entry',
  full_name='cpuinfo_s390_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hwcap', full_name='cpuinfo_s390_entry.hwcap', index=0,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=481,
)


_CPUINFO_ENTRY = _descriptor.Descriptor(
  name='cpuinfo_entry',
  full_name='cpuinfo_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x86_entry', full_name='cpuinfo_entry.x86_entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ppc64_entry', full_name='cpuinfo_entry.ppc64_entry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='s390_entry', full_name='cpuinfo_entry.s390_entry', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=622,
)

_CPUINFO_X86_ENTRY.fields_by_name['vendor_id'].enum_type = _CPUINFO_X86_ENTRY_VENDOR
_CPUINFO_X86_ENTRY_VENDOR.containing_type = _CPUINFO_X86_ENTRY
_CPUINFO_PPC64_ENTRY.fields_by_name['endian'].enum_type = _CPUINFO_PPC64_ENTRY_ENDIANNESS
_CPUINFO_PPC64_ENTRY_ENDIANNESS.containing_type = _CPUINFO_PPC64_ENTRY
_CPUINFO_ENTRY.fields_by_name['x86_entry'].message_type = _CPUINFO_X86_ENTRY
_CPUINFO_ENTRY.fields_by_name['ppc64_entry'].message_type = _CPUINFO_PPC64_ENTRY
_CPUINFO_ENTRY.fields_by_name['s390_entry'].message_type = _CPUINFO_S390_ENTRY
DESCRIPTOR.message_types_by_name['cpuinfo_x86_entry'] = _CPUINFO_X86_ENTRY
DESCRIPTOR.message_types_by_name['cpuinfo_ppc64_entry'] = _CPUINFO_PPC64_ENTRY
DESCRIPTOR.message_types_by_name['cpuinfo_s390_entry'] = _CPUINFO_S390_ENTRY
DESCRIPTOR.message_types_by_name['cpuinfo_entry'] = _CPUINFO_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

cpuinfo_x86_entry = _reflection.GeneratedProtocolMessageType('cpuinfo_x86_entry', (_message.Message,), dict(
  DESCRIPTOR = _CPUINFO_X86_ENTRY,
  __module__ = 'cpuinfo_pb2'
  # @@protoc_insertion_point(class_scope:cpuinfo_x86_entry)
  ))
_sym_db.RegisterMessage(cpuinfo_x86_entry)

cpuinfo_ppc64_entry = _reflection.GeneratedProtocolMessageType('cpuinfo_ppc64_entry', (_message.Message,), dict(
  DESCRIPTOR = _CPUINFO_PPC64_ENTRY,
  __module__ = 'cpuinfo_pb2'
  # @@protoc_insertion_point(class_scope:cpuinfo_ppc64_entry)
  ))
_sym_db.RegisterMessage(cpuinfo_ppc64_entry)

cpuinfo_s390_entry = _reflection.GeneratedProtocolMessageType('cpuinfo_s390_entry', (_message.Message,), dict(
  DESCRIPTOR = _CPUINFO_S390_ENTRY,
  __module__ = 'cpuinfo_pb2'
  # @@protoc_insertion_point(class_scope:cpuinfo_s390_entry)
  ))
_sym_db.RegisterMessage(cpuinfo_s390_entry)

cpuinfo_entry = _reflection.GeneratedProtocolMessageType('cpuinfo_entry', (_message.Message,), dict(
  DESCRIPTOR = _CPUINFO_ENTRY,
  __module__ = 'cpuinfo_pb2'
  # @@protoc_insertion_point(class_scope:cpuinfo_entry)
  ))
_sym_db.RegisterMessage(cpuinfo_entry)


# @@protoc_insertion_point(module_scope)
