# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: autofs.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='autofs.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0c\x61utofs.proto\"\x96\x01\n\x0c\x61utofs_entry\x12\n\n\x02\x66\x64\x18\x01 \x02(\x05\x12\x0c\n\x04pgrp\x18\x02 \x02(\x05\x12\x0f\n\x07timeout\x18\x03 \x02(\x05\x12\x10\n\x08minproto\x18\x04 \x02(\x05\x12\x10\n\x08maxproto\x18\x05 \x02(\x05\x12\x0c\n\x04mode\x18\x06 \x02(\x05\x12\x0b\n\x03uid\x18\x07 \x01(\x05\x12\x0b\n\x03gid\x18\x08 \x01(\x05\x12\x0f\n\x07read_fd\x18\t \x01(\x05')
)




_AUTOFS_ENTRY = _descriptor.Descriptor(
  name='autofs_entry',
  full_name='autofs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fd', full_name='autofs_entry.fd', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pgrp', full_name='autofs_entry.pgrp', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='autofs_entry.timeout', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minproto', full_name='autofs_entry.minproto', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxproto', full_name='autofs_entry.maxproto', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='autofs_entry.mode', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='autofs_entry.uid', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='autofs_entry.gid', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_fd', full_name='autofs_entry.read_fd', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17,
  serialized_end=167,
)

DESCRIPTOR.message_types_by_name['autofs_entry'] = _AUTOFS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

autofs_entry = _reflection.GeneratedProtocolMessageType('autofs_entry', (_message.Message,), dict(
  DESCRIPTOR = _AUTOFS_ENTRY,
  __module__ = 'autofs_pb2'
  # @@protoc_insertion_point(class_scope:autofs_entry)
  ))
_sym_db.RegisterMessage(autofs_entry)


# @@protoc_insertion_point(module_scope)
