# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: userns.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='userns.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0cuserns.proto\"C\n\x0euid_gid_extent\x12\r\n\x05\x66irst\x18\x01 \x02(\r\x12\x13\n\x0blower_first\x18\x02 \x02(\r\x12\r\n\x05\x63ount\x18\x03 \x02(\r\"R\n\x0cuserns_entry\x12 \n\x07uid_map\x18\x01 \x03(\x0b\x32\x0f.uid_gid_extent\x12 \n\x07gid_map\x18\x02 \x03(\x0b\x32\x0f.uid_gid_extent')
)




_UID_GID_EXTENT = _descriptor.Descriptor(
  name='uid_gid_extent',
  full_name='uid_gid_extent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first', full_name='uid_gid_extent.first', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lower_first', full_name='uid_gid_extent.lower_first', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='uid_gid_extent.count', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16,
  serialized_end=83,
)


_USERNS_ENTRY = _descriptor.Descriptor(
  name='userns_entry',
  full_name='userns_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid_map', full_name='userns_entry.uid_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid_map', full_name='userns_entry.gid_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=167,
)

_USERNS_ENTRY.fields_by_name['uid_map'].message_type = _UID_GID_EXTENT
_USERNS_ENTRY.fields_by_name['gid_map'].message_type = _UID_GID_EXTENT
DESCRIPTOR.message_types_by_name['uid_gid_extent'] = _UID_GID_EXTENT
DESCRIPTOR.message_types_by_name['userns_entry'] = _USERNS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

uid_gid_extent = _reflection.GeneratedProtocolMessageType('uid_gid_extent', (_message.Message,), dict(
  DESCRIPTOR = _UID_GID_EXTENT,
  __module__ = 'userns_pb2'
  # @@protoc_insertion_point(class_scope:uid_gid_extent)
  ))
_sym_db.RegisterMessage(uid_gid_extent)

userns_entry = _reflection.GeneratedProtocolMessageType('userns_entry', (_message.Message,), dict(
  DESCRIPTOR = _USERNS_ENTRY,
  __module__ = 'userns_pb2'
  # @@protoc_insertion_point(class_scope:userns_entry)
  ))
_sym_db.RegisterMessage(userns_entry)


# @@protoc_insertion_point(module_scope)
