# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lve.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='lve.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\tlve.proto\"]\n\x12lve_task_ids_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0e\n\x06\x63ookie\x18\x02 \x02(\r\x12\r\n\x05\x66lags\x18\x03 \x02(\r\x12\x0e\n\x06leader\x18\x04 \x02(\x08\x12\x0c\n\x04jail\x18\x05 \x02(\x08\"\xa0\x01\n\x12lve_settings_entry\x12\x0b\n\x03\x63pu\x18\x01 \x02(\x05\x12\x0c\n\x04\x63pus\x18\x02 \x02(\x05\x12\n\n\x02io\x18\x03 \x02(\x05\x12\x0e\n\x06\x65nters\x18\x04 \x02(\x05\x12\x0e\n\x06memory\x18\x05 \x02(\x05\x12\x12\n\ncpu_weight\x18\x06 \x02(\x05\x12\x12\n\nmemory_phy\x18\x07 \x02(\x05\x12\r\n\x05nproc\x18\x08 \x02(\x05\x12\x0c\n\x04iops\x18\t \x02(\x05\"H\n\tlve_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05\x66lags\x18\x02 \x02(\r\x12 \n\x03set\x18\x03 \x02(\x0b\x32\x13.lve_settings_entry')
)




_LVE_TASK_IDS_ENTRY = _descriptor.Descriptor(
  name='lve_task_ids_entry',
  full_name='lve_task_ids_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='lve_task_ids_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='lve_task_ids_entry.cookie', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='lve_task_ids_entry.flags', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leader', full_name='lve_task_ids_entry.leader', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jail', full_name='lve_task_ids_entry.jail', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13,
  serialized_end=106,
)


_LVE_SETTINGS_ENTRY = _descriptor.Descriptor(
  name='lve_settings_entry',
  full_name='lve_settings_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu', full_name='lve_settings_entry.cpu', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpus', full_name='lve_settings_entry.cpus', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='io', full_name='lve_settings_entry.io', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enters', full_name='lve_settings_entry.enters', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memory', full_name='lve_settings_entry.memory', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_weight', full_name='lve_settings_entry.cpu_weight', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memory_phy', full_name='lve_settings_entry.memory_phy', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nproc', full_name='lve_settings_entry.nproc', index=7,
      number=8, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iops', full_name='lve_settings_entry.iops', index=8,
      number=9, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=269,
)


_LVE_ENTRY = _descriptor.Descriptor(
  name='lve_entry',
  full_name='lve_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='lve_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='lve_entry.flags', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set', full_name='lve_entry.set', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=343,
)

_LVE_ENTRY.fields_by_name['set'].message_type = _LVE_SETTINGS_ENTRY
DESCRIPTOR.message_types_by_name['lve_task_ids_entry'] = _LVE_TASK_IDS_ENTRY
DESCRIPTOR.message_types_by_name['lve_settings_entry'] = _LVE_SETTINGS_ENTRY
DESCRIPTOR.message_types_by_name['lve_entry'] = _LVE_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

lve_task_ids_entry = _reflection.GeneratedProtocolMessageType('lve_task_ids_entry', (_message.Message,), dict(
  DESCRIPTOR = _LVE_TASK_IDS_ENTRY,
  __module__ = 'lve_pb2'
  # @@protoc_insertion_point(class_scope:lve_task_ids_entry)
  ))
_sym_db.RegisterMessage(lve_task_ids_entry)

lve_settings_entry = _reflection.GeneratedProtocolMessageType('lve_settings_entry', (_message.Message,), dict(
  DESCRIPTOR = _LVE_SETTINGS_ENTRY,
  __module__ = 'lve_pb2'
  # @@protoc_insertion_point(class_scope:lve_settings_entry)
  ))
_sym_db.RegisterMessage(lve_settings_entry)

lve_entry = _reflection.GeneratedProtocolMessageType('lve_entry', (_message.Message,), dict(
  DESCRIPTOR = _LVE_ENTRY,
  __module__ = 'lve_pb2'
  # @@protoc_insertion_point(class_scope:lve_entry)
  ))
_sym_db.RegisterMessage(lve_entry)


# @@protoc_insertion_point(module_scope)
