# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opts.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opts.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\nopts.proto\x1a google/protobuf/descriptor.proto\"m\n\tCRIU_Opts\x12\x0b\n\x03hex\x18\x01 \x01(\x08\x12\r\n\x05ipadd\x18\x02 \x01(\x08\x12\r\n\x05\x66lags\x18\x03 \x01(\t\x12\x0b\n\x03\x64\x65v\x18\x04 \x01(\x08\x12\x0c\n\x04odev\x18\x05 \x01(\x08\x12\x0c\n\x04\x64ict\x18\x06 \x01(\t\x12\x0c\n\x04\x63onv\x18\x07 \x01(\t:8\n\x04\x63riu\x12\x1d.google.protobuf.FieldOptions\x18\xfa\x07 \x01(\x0b\x32\n.CRIU_Opts')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


CRIU_FIELD_NUMBER = 1018
criu = _descriptor.FieldDescriptor(
  name='criu', full_name='criu', index=0,
  number=1018, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None, file=DESCRIPTOR)


_CRIU_OPTS = _descriptor.Descriptor(
  name='CRIU_Opts',
  full_name='CRIU_Opts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hex', full_name='CRIU_Opts.hex', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipadd', full_name='CRIU_Opts.ipadd', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CRIU_Opts.flags', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dev', full_name='CRIU_Opts.dev', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='odev', full_name='CRIU_Opts.odev', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dict', full_name='CRIU_Opts.dict', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conv', full_name='CRIU_Opts.conv', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=157,
)

DESCRIPTOR.message_types_by_name['CRIU_Opts'] = _CRIU_OPTS
DESCRIPTOR.extensions_by_name['criu'] = criu
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CRIU_Opts = _reflection.GeneratedProtocolMessageType('CRIU_Opts', (_message.Message,), dict(
  DESCRIPTOR = _CRIU_OPTS,
  __module__ = 'opts_pb2'
  # @@protoc_insertion_point(class_scope:CRIU_Opts)
  ))
_sym_db.RegisterMessage(CRIU_Opts)

criu.message_type = _CRIU_OPTS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(criu)

# @@protoc_insertion_point(module_scope)
