# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: timer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='timer.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0btimer.proto\"H\n\x0citimer_entry\x12\x0c\n\x04isec\x18\x01 \x02(\x04\x12\r\n\x05iusec\x18\x02 \x02(\x04\x12\x0c\n\x04vsec\x18\x03 \x02(\x04\x12\r\n\x05vusec\x18\x04 \x02(\x04\"\xbd\x01\n\x11posix_timer_entry\x12\r\n\x05it_id\x18\x01 \x02(\r\x12\x10\n\x08\x63lock_id\x18\x02 \x02(\r\x12\x10\n\x08si_signo\x18\x03 \x02(\r\x12\x17\n\x0fit_sigev_notify\x18\x04 \x02(\r\x12\x11\n\tsival_ptr\x18\x05 \x02(\x04\x12\x0f\n\x07overrun\x18\x06 \x02(\r\x12\x0c\n\x04isec\x18\x07 \x02(\x04\x12\r\n\x05insec\x18\x08 \x02(\x04\x12\x0c\n\x04vsec\x18\t \x02(\x04\x12\r\n\x05vnsec\x18\n \x02(\x04\"\x8d\x01\n\x11task_timers_entry\x12\x1b\n\x04real\x18\x01 \x02(\x0b\x32\r.itimer_entry\x12\x1b\n\x04virt\x18\x02 \x02(\x0b\x32\r.itimer_entry\x12\x1b\n\x04prof\x18\x03 \x02(\x0b\x32\r.itimer_entry\x12!\n\x05posix\x18\x04 \x03(\x0b\x32\x12.posix_timer_entry')
)




_ITIMER_ENTRY = _descriptor.Descriptor(
  name='itimer_entry',
  full_name='itimer_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isec', full_name='itimer_entry.isec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iusec', full_name='itimer_entry.iusec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vsec', full_name='itimer_entry.vsec', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vusec', full_name='itimer_entry.vusec', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15,
  serialized_end=87,
)


_POSIX_TIMER_ENTRY = _descriptor.Descriptor(
  name='posix_timer_entry',
  full_name='posix_timer_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='it_id', full_name='posix_timer_entry.it_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clock_id', full_name='posix_timer_entry.clock_id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='si_signo', full_name='posix_timer_entry.si_signo', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='it_sigev_notify', full_name='posix_timer_entry.it_sigev_notify', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sival_ptr', full_name='posix_timer_entry.sival_ptr', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overrun', full_name='posix_timer_entry.overrun', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isec', full_name='posix_timer_entry.isec', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insec', full_name='posix_timer_entry.insec', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vsec', full_name='posix_timer_entry.vsec', index=8,
      number=9, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vnsec', full_name='posix_timer_entry.vnsec', index=9,
      number=10, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=279,
)


_TASK_TIMERS_ENTRY = _descriptor.Descriptor(
  name='task_timers_entry',
  full_name='task_timers_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='real', full_name='task_timers_entry.real', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='virt', full_name='task_timers_entry.virt', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prof', full_name='task_timers_entry.prof', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posix', full_name='task_timers_entry.posix', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=423,
)

_TASK_TIMERS_ENTRY.fields_by_name['real'].message_type = _ITIMER_ENTRY
_TASK_TIMERS_ENTRY.fields_by_name['virt'].message_type = _ITIMER_ENTRY
_TASK_TIMERS_ENTRY.fields_by_name['prof'].message_type = _ITIMER_ENTRY
_TASK_TIMERS_ENTRY.fields_by_name['posix'].message_type = _POSIX_TIMER_ENTRY
DESCRIPTOR.message_types_by_name['itimer_entry'] = _ITIMER_ENTRY
DESCRIPTOR.message_types_by_name['posix_timer_entry'] = _POSIX_TIMER_ENTRY
DESCRIPTOR.message_types_by_name['task_timers_entry'] = _TASK_TIMERS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

itimer_entry = _reflection.GeneratedProtocolMessageType('itimer_entry', (_message.Message,), dict(
  DESCRIPTOR = _ITIMER_ENTRY,
  __module__ = 'timer_pb2'
  # @@protoc_insertion_point(class_scope:itimer_entry)
  ))
_sym_db.RegisterMessage(itimer_entry)

posix_timer_entry = _reflection.GeneratedProtocolMessageType('posix_timer_entry', (_message.Message,), dict(
  DESCRIPTOR = _POSIX_TIMER_ENTRY,
  __module__ = 'timer_pb2'
  # @@protoc_insertion_point(class_scope:posix_timer_entry)
  ))
_sym_db.RegisterMessage(posix_timer_entry)

task_timers_entry = _reflection.GeneratedProtocolMessageType('task_timers_entry', (_message.Message,), dict(
  DESCRIPTOR = _TASK_TIMERS_ENTRY,
  __module__ = 'timer_pb2'
  # @@protoc_insertion_point(class_scope:task_timers_entry)
  ))
_sym_db.RegisterMessage(task_timers_entry)


# @@protoc_insertion_point(module_scope)
