# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ipc-var.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ipc-var.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\ripc-var.proto\"\xfd\x02\n\ripc_var_entry\x12\x10\n\x08sem_ctls\x18\x01 \x03(\r\x12\x12\n\nmsg_ctlmax\x18\x02 \x02(\r\x12\x12\n\nmsg_ctlmnb\x18\x03 \x02(\r\x12\x12\n\nmsg_ctlmni\x18\x04 \x02(\r\x12\x13\n\x0b\x61uto_msgmni\x18\x05 \x02(\r\x12\x12\n\nshm_ctlmax\x18\x06 \x02(\x04\x12\x12\n\nshm_ctlall\x18\x07 \x02(\x04\x12\x12\n\nshm_ctlmni\x18\x08 \x02(\r\x12\x17\n\x0fshm_rmid_forced\x18\t \x02(\r\x12\x15\n\rmq_queues_max\x18\n \x02(\r\x12\x12\n\nmq_msg_max\x18\x0b \x02(\r\x12\x16\n\x0emq_msgsize_max\x18\x0c \x02(\r\x12\x16\n\x0emq_msg_default\x18\r \x01(\r\x12\x1a\n\x12mq_msgsize_default\x18\x0e \x01(\r\x12\x13\n\x0bmsg_next_id\x18\x0f \x01(\r\x12\x13\n\x0bsem_next_id\x18\x10 \x01(\r\x12\x13\n\x0bshm_next_id\x18\x11 \x01(\r')
)




_IPC_VAR_ENTRY = _descriptor.Descriptor(
  name='ipc_var_entry',
  full_name='ipc_var_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sem_ctls', full_name='ipc_var_entry.sem_ctls', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_ctlmax', full_name='ipc_var_entry.msg_ctlmax', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_ctlmnb', full_name='ipc_var_entry.msg_ctlmnb', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_ctlmni', full_name='ipc_var_entry.msg_ctlmni', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_msgmni', full_name='ipc_var_entry.auto_msgmni', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_ctlmax', full_name='ipc_var_entry.shm_ctlmax', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_ctlall', full_name='ipc_var_entry.shm_ctlall', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_ctlmni', full_name='ipc_var_entry.shm_ctlmni', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_rmid_forced', full_name='ipc_var_entry.shm_rmid_forced', index=8,
      number=9, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_queues_max', full_name='ipc_var_entry.mq_queues_max', index=9,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_msg_max', full_name='ipc_var_entry.mq_msg_max', index=10,
      number=11, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_msgsize_max', full_name='ipc_var_entry.mq_msgsize_max', index=11,
      number=12, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_msg_default', full_name='ipc_var_entry.mq_msg_default', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_msgsize_default', full_name='ipc_var_entry.mq_msgsize_default', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_next_id', full_name='ipc_var_entry.msg_next_id', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sem_next_id', full_name='ipc_var_entry.sem_next_id', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_next_id', full_name='ipc_var_entry.shm_next_id', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=399,
)

DESCRIPTOR.message_types_by_name['ipc_var_entry'] = _IPC_VAR_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ipc_var_entry = _reflection.GeneratedProtocolMessageType('ipc_var_entry', (_message.Message,), dict(
  DESCRIPTOR = _IPC_VAR_ENTRY,
  __module__ = 'ipc_var_pb2'
  # @@protoc_insertion_point(class_scope:ipc_var_entry)
  ))
_sym_db.RegisterMessage(ipc_var_entry)


# @@protoc_insertion_point(module_scope)
