# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: binfmt-misc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='binfmt-misc.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x11\x62infmt-misc.proto\"\x96\x01\n\x11\x62infmt_misc_entry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x02(\x08\x12\x13\n\x0binterpreter\x18\x03 \x02(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\t\x12\x11\n\textension\x18\x05 \x01(\t\x12\r\n\x05magic\x18\x06 \x01(\t\x12\x0c\n\x04mask\x18\x07 \x01(\t\x12\x0e\n\x06offset\x18\x08 \x01(\x05')
)




_BINFMT_MISC_ENTRY = _descriptor.Descriptor(
  name='binfmt_misc_entry',
  full_name='binfmt_misc_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='binfmt_misc_entry.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='binfmt_misc_entry.enabled', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interpreter', full_name='binfmt_misc_entry.interpreter', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='binfmt_misc_entry.flags', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension', full_name='binfmt_misc_entry.extension', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='magic', full_name='binfmt_misc_entry.magic', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='binfmt_misc_entry.mask', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='binfmt_misc_entry.offset', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=172,
)

DESCRIPTOR.message_types_by_name['binfmt_misc_entry'] = _BINFMT_MISC_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

binfmt_misc_entry = _reflection.GeneratedProtocolMessageType('binfmt_misc_entry', (_message.Message,), dict(
  DESCRIPTOR = _BINFMT_MISC_ENTRY,
  __module__ = 'binfmt_misc_pb2'
  # @@protoc_insertion_point(class_scope:binfmt_misc_entry)
  ))
_sym_db.RegisterMessage(binfmt_misc_entry)


# @@protoc_insertion_point(module_scope)
