# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fdinfo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import regfile_pb2 as regfile__pb2
import sk_inet_pb2 as sk__inet__pb2
import ns_pb2 as ns__pb2
import packet_sock_pb2 as packet__sock__pb2
import sk_netlink_pb2 as sk__netlink__pb2
import eventfd_pb2 as eventfd__pb2
import eventpoll_pb2 as eventpoll__pb2
import signalfd_pb2 as signalfd__pb2
import tun_pb2 as tun__pb2
import timerfd_pb2 as timerfd__pb2
import fsnotify_pb2 as fsnotify__pb2
import ext_file_pb2 as ext__file__pb2
import sk_unix_pb2 as sk__unix__pb2
import fifo_pb2 as fifo__pb2
import pipe_pb2 as pipe__pb2
import tty_pb2 as tty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fdinfo.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0c\x66\x64info.proto\x1a\rregfile.proto\x1a\rsk-inet.proto\x1a\x08ns.proto\x1a\x11packet-sock.proto\x1a\x10sk-netlink.proto\x1a\reventfd.proto\x1a\x0f\x65ventpoll.proto\x1a\x0esignalfd.proto\x1a\ttun.proto\x1a\rtimerfd.proto\x1a\x0e\x66snotify.proto\x1a\x0e\x65xt-file.proto\x1a\rsk-unix.proto\x1a\nfifo.proto\x1a\npipe.proto\x1a\ttty.proto\"\x80\x01\n\x0c\x66\x64info_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05\x66lags\x18\x02 \x02(\r\x12\x17\n\x04type\x18\x03 \x02(\x0e\x32\t.fd_types\x12\n\n\x02\x66\x64\x18\x04 \x02(\r\x12\x1e\n\x16xattr_security_selinux\x18\x05 \x01(\t\x12\x10\n\x08out_jail\x18\x06 \x01(\x08\"\xc0\x04\n\nfile_entry\x12\x17\n\x04type\x18\x01 \x02(\x0e\x32\t.fd_types\x12\n\n\x02id\x18\x02 \x02(\r\x12\x1c\n\x03reg\x18\x03 \x01(\x0b\x32\x0f.reg_file_entry\x12\x1b\n\x03isk\x18\x04 \x01(\x0b\x32\x0e.inet_sk_entry\x12\x1b\n\x03nsf\x18\x05 \x01(\x0b\x32\x0e.ns_file_entry\x12\x1f\n\x03psk\x18\x06 \x01(\x0b\x32\x12.packet_sock_entry\x12\x1f\n\x04nlsk\x18\x07 \x01(\x0b\x32\x11.netlink_sk_entry\x12 \n\x03\x65\x66\x64\x18\x08 \x01(\x0b\x32\x13.eventfd_file_entry\x12#\n\x04\x65pfd\x18\t \x01(\x0b\x32\x15.eventpoll_file_entry\x12\x1d\n\x04sgfd\x18\n \x01(\x0b\x32\x0f.signalfd_entry\x12\x1c\n\x04tunf\x18\x0b \x01(\x0b\x32\x0e.tunfile_entry\x12\x1b\n\x03tfd\x18\x0c \x01(\x0b\x32\x0e.timerfd_entry\x12 \n\x03ify\x18\r \x01(\x0b\x32\x13.inotify_file_entry\x12!\n\x03\x66\x66y\x18\x0e \x01(\x0b\x32\x14.fanotify_file_entry\x12\x1c\n\x03\x65xt\x18\x0f \x01(\x0b\x32\x0f.ext_file_entry\x12\x1b\n\x03usk\x18\x10 \x01(\x0b\x32\x0e.unix_sk_entry\x12\x19\n\x04\x66ifo\x18\x11 \x01(\x0b\x32\x0b.fifo_entry\x12\x19\n\x04pipe\x18\x12 \x01(\x0b\x32\x0b.pipe_entry\x12\x1c\n\x03tty\x18\x13 \x01(\x0b\x32\x0f.tty_file_entry*\xfd\x01\n\x08\x66\x64_types\x12\x07\n\x03UND\x10\x00\x12\x07\n\x03REG\x10\x01\x12\x08\n\x04PIPE\x10\x02\x12\x08\n\x04\x46IFO\x10\x03\x12\n\n\x06INETSK\x10\x04\x12\n\n\x06UNIXSK\x10\x05\x12\x0b\n\x07\x45VENTFD\x10\x06\x12\r\n\tEVENTPOLL\x10\x07\x12\x0b\n\x07INOTIFY\x10\x08\x12\x0c\n\x08SIGNALFD\x10\t\x12\x0c\n\x08PACKETSK\x10\n\x12\x07\n\x03TTY\x10\x0b\x12\x0c\n\x08\x46\x41NOTIFY\x10\x0c\x12\r\n\tNETLINKSK\x10\r\x12\x06\n\x02NS\x10\x0e\x12\x08\n\x04TUNF\x10\x0f\x12\x07\n\x03\x45XT\x10\x10\x12\x0b\n\x07TIMERFD\x10\x11\x12\r\n\x07\x43TL_TTY\x10\xfe\xff\x03\x12\x11\n\x0b\x41UTOFS_PIPE\x10\xff\xff\x03')
  ,
  dependencies=[regfile__pb2.DESCRIPTOR,sk__inet__pb2.DESCRIPTOR,ns__pb2.DESCRIPTOR,packet__sock__pb2.DESCRIPTOR,sk__netlink__pb2.DESCRIPTOR,eventfd__pb2.DESCRIPTOR,eventpoll__pb2.DESCRIPTOR,signalfd__pb2.DESCRIPTOR,tun__pb2.DESCRIPTOR,timerfd__pb2.DESCRIPTOR,fsnotify__pb2.DESCRIPTOR,ext__file__pb2.DESCRIPTOR,sk__unix__pb2.DESCRIPTOR,fifo__pb2.DESCRIPTOR,pipe__pb2.DESCRIPTOR,tty__pb2.DESCRIPTOR,])

_FD_TYPES = _descriptor.EnumDescriptor(
  name='fd_types',
  full_name='fd_types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REG', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIFO', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INETSK', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIXSK', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENTFD', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENTPOLL', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INOTIFY', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNALFD', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PACKETSK', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TTY', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANOTIFY', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETLINKSK', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NS', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TUNF', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXT', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMERFD', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CTL_TTY', index=18, number=65534,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTOFS_PIPE', index=19, number=65535,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=960,
  serialized_end=1213,
)
_sym_db.RegisterEnumDescriptor(_FD_TYPES)

fd_types = enum_type_wrapper.EnumTypeWrapper(_FD_TYPES)
UND = 0
REG = 1
PIPE = 2
FIFO = 3
INETSK = 4
UNIXSK = 5
EVENTFD = 6
EVENTPOLL = 7
INOTIFY = 8
SIGNALFD = 9
PACKETSK = 10
TTY = 11
FANOTIFY = 12
NETLINKSK = 13
NS = 14
TUNF = 15
EXT = 16
TIMERFD = 17
CTL_TTY = 65534
AUTOFS_PIPE = 65535



_FDINFO_ENTRY = _descriptor.Descriptor(
  name='fdinfo_entry',
  full_name='fdinfo_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='fdinfo_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='fdinfo_entry.flags', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='fdinfo_entry.type', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fd', full_name='fdinfo_entry.fd', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xattr_security_selinux', full_name='fdinfo_entry.xattr_security_selinux', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_jail', full_name='fdinfo_entry.out_jail', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=378,
)


_FILE_ENTRY = _descriptor.Descriptor(
  name='file_entry',
  full_name='file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='file_entry.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='file_entry.id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reg', full_name='file_entry.reg', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isk', full_name='file_entry.isk', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nsf', full_name='file_entry.nsf', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='psk', full_name='file_entry.psk', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nlsk', full_name='file_entry.nlsk', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='efd', full_name='file_entry.efd', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epfd', full_name='file_entry.epfd', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sgfd', full_name='file_entry.sgfd', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tunf', full_name='file_entry.tunf', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tfd', full_name='file_entry.tfd', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ify', full_name='file_entry.ify', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ffy', full_name='file_entry.ffy', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext', full_name='file_entry.ext', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usk', full_name='file_entry.usk', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fifo', full_name='file_entry.fifo', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipe', full_name='file_entry.pipe', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tty', full_name='file_entry.tty', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=381,
  serialized_end=957,
)

_FDINFO_ENTRY.fields_by_name['type'].enum_type = _FD_TYPES
_FILE_ENTRY.fields_by_name['type'].enum_type = _FD_TYPES
_FILE_ENTRY.fields_by_name['reg'].message_type = regfile__pb2._REG_FILE_ENTRY
_FILE_ENTRY.fields_by_name['isk'].message_type = sk__inet__pb2._INET_SK_ENTRY
_FILE_ENTRY.fields_by_name['nsf'].message_type = ns__pb2._NS_FILE_ENTRY
_FILE_ENTRY.fields_by_name['psk'].message_type = packet__sock__pb2._PACKET_SOCK_ENTRY
_FILE_ENTRY.fields_by_name['nlsk'].message_type = sk__netlink__pb2._NETLINK_SK_ENTRY
_FILE_ENTRY.fields_by_name['efd'].message_type = eventfd__pb2._EVENTFD_FILE_ENTRY
_FILE_ENTRY.fields_by_name['epfd'].message_type = eventpoll__pb2._EVENTPOLL_FILE_ENTRY
_FILE_ENTRY.fields_by_name['sgfd'].message_type = signalfd__pb2._SIGNALFD_ENTRY
_FILE_ENTRY.fields_by_name['tunf'].message_type = tun__pb2._TUNFILE_ENTRY
_FILE_ENTRY.fields_by_name['tfd'].message_type = timerfd__pb2._TIMERFD_ENTRY
_FILE_ENTRY.fields_by_name['ify'].message_type = fsnotify__pb2._INOTIFY_FILE_ENTRY
_FILE_ENTRY.fields_by_name['ffy'].message_type = fsnotify__pb2._FANOTIFY_FILE_ENTRY
_FILE_ENTRY.fields_by_name['ext'].message_type = ext__file__pb2._EXT_FILE_ENTRY
_FILE_ENTRY.fields_by_name['usk'].message_type = sk__unix__pb2._UNIX_SK_ENTRY
_FILE_ENTRY.fields_by_name['fifo'].message_type = fifo__pb2._FIFO_ENTRY
_FILE_ENTRY.fields_by_name['pipe'].message_type = pipe__pb2._PIPE_ENTRY
_FILE_ENTRY.fields_by_name['tty'].message_type = tty__pb2._TTY_FILE_ENTRY
DESCRIPTOR.message_types_by_name['fdinfo_entry'] = _FDINFO_ENTRY
DESCRIPTOR.message_types_by_name['file_entry'] = _FILE_ENTRY
DESCRIPTOR.enum_types_by_name['fd_types'] = _FD_TYPES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

fdinfo_entry = _reflection.GeneratedProtocolMessageType('fdinfo_entry', (_message.Message,), dict(
  DESCRIPTOR = _FDINFO_ENTRY,
  __module__ = 'fdinfo_pb2'
  # @@protoc_insertion_point(class_scope:fdinfo_entry)
  ))
_sym_db.RegisterMessage(fdinfo_entry)

file_entry = _reflection.GeneratedProtocolMessageType('file_entry', (_message.Message,), dict(
  DESCRIPTOR = _FILE_ENTRY,
  __module__ = 'fdinfo_pb2'
  # @@protoc_insertion_point(class_scope:file_entry)
  ))
_sym_db.RegisterMessage(file_entry)


# @@protoc_insertion_point(module_scope)
