# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sk-netlink.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sk-netlink.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x10sk-netlink.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\"\xf1\x01\n\x10netlink_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x10\n\x08protocol\x18\x03 \x02(\r\x12\r\n\x05state\x18\x04 \x02(\r\x12\x14\n\x05\x66lags\x18\x06 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0e\n\x06portid\x18\x07 \x02(\r\x12\x0e\n\x06groups\x18\x08 \x03(\r\x12\x12\n\ndst_portid\x18\t \x02(\r\x12\x11\n\tdst_group\x18\n \x02(\r\x12\x19\n\x04\x66own\x18\x0b \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x0c \x02(\x0b\x32\x0e.sk_opts_entry\x12\r\n\x05ns_id\x18\r \x01(\r')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,fown__pb2.DESCRIPTOR,sk__opts__pb2.DESCRIPTOR,])




_NETLINK_SK_ENTRY = _descriptor.Descriptor(
  name='netlink_sk_entry',
  full_name='netlink_sk_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='netlink_sk_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ino', full_name='netlink_sk_entry.ino', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='netlink_sk_entry.protocol', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='netlink_sk_entry.state', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='netlink_sk_entry.flags', index=4,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portid', full_name='netlink_sk_entry.portid', index=5,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='netlink_sk_entry.groups', index=6,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_portid', full_name='netlink_sk_entry.dst_portid', index=7,
      number=9, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_group', full_name='netlink_sk_entry.dst_group', index=8,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='netlink_sk_entry.fown', index=9,
      number=11, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opts', full_name='netlink_sk_entry.opts', index=10,
      number=12, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_id', full_name='netlink_sk_entry.ns_id', index=11,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=301,
)

_NETLINK_SK_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
_NETLINK_SK_ENTRY.fields_by_name['opts'].message_type = sk__opts__pb2._SK_OPTS_ENTRY
DESCRIPTOR.message_types_by_name['netlink_sk_entry'] = _NETLINK_SK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

netlink_sk_entry = _reflection.GeneratedProtocolMessageType('netlink_sk_entry', (_message.Message,), dict(
  DESCRIPTOR = _NETLINK_SK_ENTRY,
  __module__ = 'sk_netlink_pb2'
  # @@protoc_insertion_point(class_scope:netlink_sk_entry)
  ))
_sym_db.RegisterMessage(netlink_sk_entry)


_NETLINK_SK_ENTRY.fields_by_name['flags'].has_options = True
_NETLINK_SK_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)
