# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: utsns.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='utsns.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0butsns.proto\"3\n\x0butsns_entry\x12\x10\n\x08nodename\x18\x01 \x02(\t\x12\x12\n\ndomainname\x18\x02 \x02(\t')
)




_UTSNS_ENTRY = _descriptor.Descriptor(
  name='utsns_entry',
  full_name='utsns_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodename', full_name='utsns_entry.nodename', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domainname', full_name='utsns_entry.domainname', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15,
  serialized_end=66,
)

DESCRIPTOR.message_types_by_name['utsns_entry'] = _UTSNS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

utsns_entry = _reflection.GeneratedProtocolMessageType('utsns_entry', (_message.Message,), dict(
  DESCRIPTOR = _UTSNS_ENTRY,
  __module__ = 'utsns_pb2'
  # @@protoc_insertion_point(class_scope:utsns_entry)
  ))
_sym_db.RegisterMessage(utsns_entry)


# @@protoc_insertion_point(module_scope)
