# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ghost-file.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import time_pb2 as time__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ghost-file.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x10ghost-file.proto\x1a\nopts.proto\x1a\ntime.proto\"\xc3\x01\n\x10ghost_file_entry\x12\x0b\n\x03uid\x18\x01 \x02(\r\x12\x0b\n\x03gid\x18\x02 \x02(\r\x12\x0c\n\x04mode\x18\x03 \x02(\r\x12\x12\n\x03\x64\x65v\x18\x04 \x01(\rB\x05\xd2?\x02 \x01\x12\x0b\n\x03ino\x18\x05 \x01(\x04\x12\x18\n\x04rdev\x18\x06 \x01(\rB\n\xd2?\x02 \x01\xd2?\x02(\x01\x12\x16\n\x04\x61tim\x18\x07 \x01(\x0b\x32\x08.timeval\x12\x16\n\x04mtim\x18\x08 \x01(\x0b\x32\x08.timeval\x12\x0e\n\x06\x63hunks\x18\t \x01(\x08\x12\x0c\n\x04size\x18\n \x01(\x04\"-\n\x11ghost_chunk_entry\x12\x0b\n\x03len\x18\x01 \x02(\x04\x12\x0b\n\x03off\x18\x02 \x02(\x04')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,time__pb2.DESCRIPTOR,])




_GHOST_FILE_ENTRY = _descriptor.Descriptor(
  name='ghost_file_entry',
  full_name='ghost_file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='ghost_file_entry.uid', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='ghost_file_entry.gid', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='ghost_file_entry.mode', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dev', full_name='ghost_file_entry.dev', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ino', full_name='ghost_file_entry.ino', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rdev', full_name='ghost_file_entry.rdev', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001\322?\002(\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='atim', full_name='ghost_file_entry.atim', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mtim', full_name='ghost_file_entry.mtim', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunks', full_name='ghost_file_entry.chunks', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='ghost_file_entry.size', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=240,
)


_GHOST_CHUNK_ENTRY = _descriptor.Descriptor(
  name='ghost_chunk_entry',
  full_name='ghost_chunk_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='len', full_name='ghost_chunk_entry.len', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='off', full_name='ghost_chunk_entry.off', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=287,
)

_GHOST_FILE_ENTRY.fields_by_name['atim'].message_type = time__pb2._TIMEVAL
_GHOST_FILE_ENTRY.fields_by_name['mtim'].message_type = time__pb2._TIMEVAL
DESCRIPTOR.message_types_by_name['ghost_file_entry'] = _GHOST_FILE_ENTRY
DESCRIPTOR.message_types_by_name['ghost_chunk_entry'] = _GHOST_CHUNK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ghost_file_entry = _reflection.GeneratedProtocolMessageType('ghost_file_entry', (_message.Message,), dict(
  DESCRIPTOR = _GHOST_FILE_ENTRY,
  __module__ = 'ghost_file_pb2'
  # @@protoc_insertion_point(class_scope:ghost_file_entry)
  ))
_sym_db.RegisterMessage(ghost_file_entry)

ghost_chunk_entry = _reflection.GeneratedProtocolMessageType('ghost_chunk_entry', (_message.Message,), dict(
  DESCRIPTOR = _GHOST_CHUNK_ENTRY,
  __module__ = 'ghost_file_pb2'
  # @@protoc_insertion_point(class_scope:ghost_chunk_entry)
  ))
_sym_db.RegisterMessage(ghost_chunk_entry)


_GHOST_FILE_ENTRY.fields_by_name['dev'].has_options = True
_GHOST_FILE_ENTRY.fields_by_name['dev']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001'))
_GHOST_FILE_ENTRY.fields_by_name['rdev'].has_options = True
_GHOST_FILE_ENTRY.fields_by_name['rdev']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001\322?\002(\001'))
# @@protoc_insertion_point(module_scope)
